
from typing import Optional

from gi.repository import GObject
from gi.repository import GdkPixbuf
import cairo


BUTTON_MIDDLE: int = ...
BUTTON_PRIMARY: int = ...
BUTTON_SECONDARY: int = ...
CURRENT_TIME: int = ...
EVENT_PROPAGATE: int = ...
EVENT_STOP: int = ...
KEY_0: int = ...
KEY_1: int = ...
KEY_2: int = ...
KEY_3: int = ...
KEY_3270_AltCursor: int = ...
KEY_3270_Attn: int = ...
KEY_3270_BackTab: int = ...
KEY_3270_ChangeScreen: int = ...
KEY_3270_Copy: int = ...
KEY_3270_CursorBlink: int = ...
KEY_3270_CursorSelect: int = ...
KEY_3270_DeleteWord: int = ...
KEY_3270_Duplicate: int = ...
KEY_3270_Enter: int = ...
KEY_3270_EraseEOF: int = ...
KEY_3270_EraseInput: int = ...
KEY_3270_ExSelect: int = ...
KEY_3270_FieldMark: int = ...
KEY_3270_Ident: int = ...
KEY_3270_Jump: int = ...
KEY_3270_KeyClick: int = ...
KEY_3270_Left2: int = ...
KEY_3270_PA1: int = ...
KEY_3270_PA2: int = ...
KEY_3270_PA3: int = ...
KEY_3270_Play: int = ...
KEY_3270_PrintScreen: int = ...
KEY_3270_Quit: int = ...
KEY_3270_Record: int = ...
KEY_3270_Reset: int = ...
KEY_3270_Right2: int = ...
KEY_3270_Rule: int = ...
KEY_3270_Setup: int = ...
KEY_3270_Test: int = ...
KEY_4: int = ...
KEY_5: int = ...
KEY_6: int = ...
KEY_7: int = ...
KEY_8: int = ...
KEY_9: int = ...
KEY_A: int = ...
KEY_AE: int = ...
KEY_Aacute: int = ...
KEY_Abelowdot: int = ...
KEY_Abreve: int = ...
KEY_Abreveacute: int = ...
KEY_Abrevebelowdot: int = ...
KEY_Abrevegrave: int = ...
KEY_Abrevehook: int = ...
KEY_Abrevetilde: int = ...
KEY_AccessX_Enable: int = ...
KEY_AccessX_Feedback_Enable: int = ...
KEY_Acircumflex: int = ...
KEY_Acircumflexacute: int = ...
KEY_Acircumflexbelowdot: int = ...
KEY_Acircumflexgrave: int = ...
KEY_Acircumflexhook: int = ...
KEY_Acircumflextilde: int = ...
KEY_AddFavorite: int = ...
KEY_Adiaeresis: int = ...
KEY_Agrave: int = ...
KEY_Ahook: int = ...
KEY_Alt_L: int = ...
KEY_Alt_R: int = ...
KEY_Amacron: int = ...
KEY_Aogonek: int = ...
KEY_ApplicationLeft: int = ...
KEY_ApplicationRight: int = ...
KEY_Arabic_0: int = ...
KEY_Arabic_1: int = ...
KEY_Arabic_2: int = ...
KEY_Arabic_3: int = ...
KEY_Arabic_4: int = ...
KEY_Arabic_5: int = ...
KEY_Arabic_6: int = ...
KEY_Arabic_7: int = ...
KEY_Arabic_8: int = ...
KEY_Arabic_9: int = ...
KEY_Arabic_ain: int = ...
KEY_Arabic_alef: int = ...
KEY_Arabic_alefmaksura: int = ...
KEY_Arabic_beh: int = ...
KEY_Arabic_comma: int = ...
KEY_Arabic_dad: int = ...
KEY_Arabic_dal: int = ...
KEY_Arabic_damma: int = ...
KEY_Arabic_dammatan: int = ...
KEY_Arabic_ddal: int = ...
KEY_Arabic_farsi_yeh: int = ...
KEY_Arabic_fatha: int = ...
KEY_Arabic_fathatan: int = ...
KEY_Arabic_feh: int = ...
KEY_Arabic_fullstop: int = ...
KEY_Arabic_gaf: int = ...
KEY_Arabic_ghain: int = ...
KEY_Arabic_ha: int = ...
KEY_Arabic_hah: int = ...
KEY_Arabic_hamza: int = ...
KEY_Arabic_hamza_above: int = ...
KEY_Arabic_hamza_below: int = ...
KEY_Arabic_hamzaonalef: int = ...
KEY_Arabic_hamzaonwaw: int = ...
KEY_Arabic_hamzaonyeh: int = ...
KEY_Arabic_hamzaunderalef: int = ...
KEY_Arabic_heh: int = ...
KEY_Arabic_heh_doachashmee: int = ...
KEY_Arabic_heh_goal: int = ...
KEY_Arabic_jeem: int = ...
KEY_Arabic_jeh: int = ...
KEY_Arabic_kaf: int = ...
KEY_Arabic_kasra: int = ...
KEY_Arabic_kasratan: int = ...
KEY_Arabic_keheh: int = ...
KEY_Arabic_khah: int = ...
KEY_Arabic_lam: int = ...
KEY_Arabic_madda_above: int = ...
KEY_Arabic_maddaonalef: int = ...
KEY_Arabic_meem: int = ...
KEY_Arabic_noon: int = ...
KEY_Arabic_noon_ghunna: int = ...
KEY_Arabic_peh: int = ...
KEY_Arabic_percent: int = ...
KEY_Arabic_qaf: int = ...
KEY_Arabic_question_mark: int = ...
KEY_Arabic_ra: int = ...
KEY_Arabic_rreh: int = ...
KEY_Arabic_sad: int = ...
KEY_Arabic_seen: int = ...
KEY_Arabic_semicolon: int = ...
KEY_Arabic_shadda: int = ...
KEY_Arabic_sheen: int = ...
KEY_Arabic_sukun: int = ...
KEY_Arabic_superscript_alef: int = ...
KEY_Arabic_switch: int = ...
KEY_Arabic_tah: int = ...
KEY_Arabic_tatweel: int = ...
KEY_Arabic_tcheh: int = ...
KEY_Arabic_teh: int = ...
KEY_Arabic_tehmarbuta: int = ...
KEY_Arabic_thal: int = ...
KEY_Arabic_theh: int = ...
KEY_Arabic_tteh: int = ...
KEY_Arabic_veh: int = ...
KEY_Arabic_waw: int = ...
KEY_Arabic_yeh: int = ...
KEY_Arabic_yeh_baree: int = ...
KEY_Arabic_zah: int = ...
KEY_Arabic_zain: int = ...
KEY_Aring: int = ...
KEY_Armenian_AT: int = ...
KEY_Armenian_AYB: int = ...
KEY_Armenian_BEN: int = ...
KEY_Armenian_CHA: int = ...
KEY_Armenian_DA: int = ...
KEY_Armenian_DZA: int = ...
KEY_Armenian_E: int = ...
KEY_Armenian_FE: int = ...
KEY_Armenian_GHAT: int = ...
KEY_Armenian_GIM: int = ...
KEY_Armenian_HI: int = ...
KEY_Armenian_HO: int = ...
KEY_Armenian_INI: int = ...
KEY_Armenian_JE: int = ...
KEY_Armenian_KE: int = ...
KEY_Armenian_KEN: int = ...
KEY_Armenian_KHE: int = ...
KEY_Armenian_LYUN: int = ...
KEY_Armenian_MEN: int = ...
KEY_Armenian_NU: int = ...
KEY_Armenian_O: int = ...
KEY_Armenian_PE: int = ...
KEY_Armenian_PYUR: int = ...
KEY_Armenian_RA: int = ...
KEY_Armenian_RE: int = ...
KEY_Armenian_SE: int = ...
KEY_Armenian_SHA: int = ...
KEY_Armenian_TCHE: int = ...
KEY_Armenian_TO: int = ...
KEY_Armenian_TSA: int = ...
KEY_Armenian_TSO: int = ...
KEY_Armenian_TYUN: int = ...
KEY_Armenian_VEV: int = ...
KEY_Armenian_VO: int = ...
KEY_Armenian_VYUN: int = ...
KEY_Armenian_YECH: int = ...
KEY_Armenian_ZA: int = ...
KEY_Armenian_ZHE: int = ...
KEY_Armenian_accent: int = ...
KEY_Armenian_amanak: int = ...
KEY_Armenian_apostrophe: int = ...
KEY_Armenian_at: int = ...
KEY_Armenian_ayb: int = ...
KEY_Armenian_ben: int = ...
KEY_Armenian_but: int = ...
KEY_Armenian_cha: int = ...
KEY_Armenian_da: int = ...
KEY_Armenian_dza: int = ...
KEY_Armenian_e: int = ...
KEY_Armenian_exclam: int = ...
KEY_Armenian_fe: int = ...
KEY_Armenian_full_stop: int = ...
KEY_Armenian_ghat: int = ...
KEY_Armenian_gim: int = ...
KEY_Armenian_hi: int = ...
KEY_Armenian_ho: int = ...
KEY_Armenian_hyphen: int = ...
KEY_Armenian_ini: int = ...
KEY_Armenian_je: int = ...
KEY_Armenian_ke: int = ...
KEY_Armenian_ken: int = ...
KEY_Armenian_khe: int = ...
KEY_Armenian_ligature_ew: int = ...
KEY_Armenian_lyun: int = ...
KEY_Armenian_men: int = ...
KEY_Armenian_nu: int = ...
KEY_Armenian_o: int = ...
KEY_Armenian_paruyk: int = ...
KEY_Armenian_pe: int = ...
KEY_Armenian_pyur: int = ...
KEY_Armenian_question: int = ...
KEY_Armenian_ra: int = ...
KEY_Armenian_re: int = ...
KEY_Armenian_se: int = ...
KEY_Armenian_separation_mark: int = ...
KEY_Armenian_sha: int = ...
KEY_Armenian_shesht: int = ...
KEY_Armenian_tche: int = ...
KEY_Armenian_to: int = ...
KEY_Armenian_tsa: int = ...
KEY_Armenian_tso: int = ...
KEY_Armenian_tyun: int = ...
KEY_Armenian_verjaket: int = ...
KEY_Armenian_vev: int = ...
KEY_Armenian_vo: int = ...
KEY_Armenian_vyun: int = ...
KEY_Armenian_yech: int = ...
KEY_Armenian_yentamna: int = ...
KEY_Armenian_za: int = ...
KEY_Armenian_zhe: int = ...
KEY_Atilde: int = ...
KEY_AudibleBell_Enable: int = ...
KEY_AudioCycleTrack: int = ...
KEY_AudioForward: int = ...
KEY_AudioLowerVolume: int = ...
KEY_AudioMedia: int = ...
KEY_AudioMicMute: int = ...
KEY_AudioMute: int = ...
KEY_AudioNext: int = ...
KEY_AudioPause: int = ...
KEY_AudioPlay: int = ...
KEY_AudioPreset: int = ...
KEY_AudioPrev: int = ...
KEY_AudioRaiseVolume: int = ...
KEY_AudioRandomPlay: int = ...
KEY_AudioRecord: int = ...
KEY_AudioRepeat: int = ...
KEY_AudioRewind: int = ...
KEY_AudioStop: int = ...
KEY_Away: int = ...
KEY_B: int = ...
KEY_Babovedot: int = ...
KEY_Back: int = ...
KEY_BackForward: int = ...
KEY_BackSpace: int = ...
KEY_Battery: int = ...
KEY_Begin: int = ...
KEY_Blue: int = ...
KEY_Bluetooth: int = ...
KEY_Book: int = ...
KEY_BounceKeys_Enable: int = ...
KEY_Break: int = ...
KEY_BrightnessAdjust: int = ...
KEY_Byelorussian_SHORTU: int = ...
KEY_Byelorussian_shortu: int = ...
KEY_C: int = ...
KEY_CD: int = ...
KEY_CH: int = ...
KEY_C_H: int = ...
KEY_C_h: int = ...
KEY_Cabovedot: int = ...
KEY_Cacute: int = ...
KEY_Calculator: int = ...
KEY_Calendar: int = ...
KEY_Cancel: int = ...
KEY_Caps_Lock: int = ...
KEY_Ccaron: int = ...
KEY_Ccedilla: int = ...
KEY_Ccircumflex: int = ...
KEY_Ch: int = ...
KEY_Clear: int = ...
KEY_ClearGrab: int = ...
KEY_Close: int = ...
KEY_Codeinput: int = ...
KEY_ColonSign: int = ...
KEY_Community: int = ...
KEY_ContrastAdjust: int = ...
KEY_Control_L: int = ...
KEY_Control_R: int = ...
KEY_Copy: int = ...
KEY_CruzeiroSign: int = ...
KEY_Cut: int = ...
KEY_CycleAngle: int = ...
KEY_Cyrillic_A: int = ...
KEY_Cyrillic_BE: int = ...
KEY_Cyrillic_CHE: int = ...
KEY_Cyrillic_CHE_descender: int = ...
KEY_Cyrillic_CHE_vertstroke: int = ...
KEY_Cyrillic_DE: int = ...
KEY_Cyrillic_DZHE: int = ...
KEY_Cyrillic_E: int = ...
KEY_Cyrillic_EF: int = ...
KEY_Cyrillic_EL: int = ...
KEY_Cyrillic_EM: int = ...
KEY_Cyrillic_EN: int = ...
KEY_Cyrillic_EN_descender: int = ...
KEY_Cyrillic_ER: int = ...
KEY_Cyrillic_ES: int = ...
KEY_Cyrillic_GHE: int = ...
KEY_Cyrillic_GHE_bar: int = ...
KEY_Cyrillic_HA: int = ...
KEY_Cyrillic_HARDSIGN: int = ...
KEY_Cyrillic_HA_descender: int = ...
KEY_Cyrillic_I: int = ...
KEY_Cyrillic_IE: int = ...
KEY_Cyrillic_IO: int = ...
KEY_Cyrillic_I_macron: int = ...
KEY_Cyrillic_JE: int = ...
KEY_Cyrillic_KA: int = ...
KEY_Cyrillic_KA_descender: int = ...
KEY_Cyrillic_KA_vertstroke: int = ...
KEY_Cyrillic_LJE: int = ...
KEY_Cyrillic_NJE: int = ...
KEY_Cyrillic_O: int = ...
KEY_Cyrillic_O_bar: int = ...
KEY_Cyrillic_PE: int = ...
KEY_Cyrillic_SCHWA: int = ...
KEY_Cyrillic_SHA: int = ...
KEY_Cyrillic_SHCHA: int = ...
KEY_Cyrillic_SHHA: int = ...
KEY_Cyrillic_SHORTI: int = ...
KEY_Cyrillic_SOFTSIGN: int = ...
KEY_Cyrillic_TE: int = ...
KEY_Cyrillic_TSE: int = ...
KEY_Cyrillic_U: int = ...
KEY_Cyrillic_U_macron: int = ...
KEY_Cyrillic_U_straight: int = ...
KEY_Cyrillic_U_straight_bar: int = ...
KEY_Cyrillic_VE: int = ...
KEY_Cyrillic_YA: int = ...
KEY_Cyrillic_YERU: int = ...
KEY_Cyrillic_YU: int = ...
KEY_Cyrillic_ZE: int = ...
KEY_Cyrillic_ZHE: int = ...
KEY_Cyrillic_ZHE_descender: int = ...
KEY_Cyrillic_a: int = ...
KEY_Cyrillic_be: int = ...
KEY_Cyrillic_che: int = ...
KEY_Cyrillic_che_descender: int = ...
KEY_Cyrillic_che_vertstroke: int = ...
KEY_Cyrillic_de: int = ...
KEY_Cyrillic_dzhe: int = ...
KEY_Cyrillic_e: int = ...
KEY_Cyrillic_ef: int = ...
KEY_Cyrillic_el: int = ...
KEY_Cyrillic_em: int = ...
KEY_Cyrillic_en: int = ...
KEY_Cyrillic_en_descender: int = ...
KEY_Cyrillic_er: int = ...
KEY_Cyrillic_es: int = ...
KEY_Cyrillic_ghe: int = ...
KEY_Cyrillic_ghe_bar: int = ...
KEY_Cyrillic_ha: int = ...
KEY_Cyrillic_ha_descender: int = ...
KEY_Cyrillic_hardsign: int = ...
KEY_Cyrillic_i: int = ...
KEY_Cyrillic_i_macron: int = ...
KEY_Cyrillic_ie: int = ...
KEY_Cyrillic_io: int = ...
KEY_Cyrillic_je: int = ...
KEY_Cyrillic_ka: int = ...
KEY_Cyrillic_ka_descender: int = ...
KEY_Cyrillic_ka_vertstroke: int = ...
KEY_Cyrillic_lje: int = ...
KEY_Cyrillic_nje: int = ...
KEY_Cyrillic_o: int = ...
KEY_Cyrillic_o_bar: int = ...
KEY_Cyrillic_pe: int = ...
KEY_Cyrillic_schwa: int = ...
KEY_Cyrillic_sha: int = ...
KEY_Cyrillic_shcha: int = ...
KEY_Cyrillic_shha: int = ...
KEY_Cyrillic_shorti: int = ...
KEY_Cyrillic_softsign: int = ...
KEY_Cyrillic_te: int = ...
KEY_Cyrillic_tse: int = ...
KEY_Cyrillic_u: int = ...
KEY_Cyrillic_u_macron: int = ...
KEY_Cyrillic_u_straight: int = ...
KEY_Cyrillic_u_straight_bar: int = ...
KEY_Cyrillic_ve: int = ...
KEY_Cyrillic_ya: int = ...
KEY_Cyrillic_yeru: int = ...
KEY_Cyrillic_yu: int = ...
KEY_Cyrillic_ze: int = ...
KEY_Cyrillic_zhe: int = ...
KEY_Cyrillic_zhe_descender: int = ...
KEY_D: int = ...
KEY_DOS: int = ...
KEY_Dabovedot: int = ...
KEY_Dcaron: int = ...
KEY_Delete: int = ...
KEY_Display: int = ...
KEY_Documents: int = ...
KEY_DongSign: int = ...
KEY_Down: int = ...
KEY_Dstroke: int = ...
KEY_E: int = ...
KEY_ENG: int = ...
KEY_ETH: int = ...
KEY_EZH: int = ...
KEY_Eabovedot: int = ...
KEY_Eacute: int = ...
KEY_Ebelowdot: int = ...
KEY_Ecaron: int = ...
KEY_Ecircumflex: int = ...
KEY_Ecircumflexacute: int = ...
KEY_Ecircumflexbelowdot: int = ...
KEY_Ecircumflexgrave: int = ...
KEY_Ecircumflexhook: int = ...
KEY_Ecircumflextilde: int = ...
KEY_EcuSign: int = ...
KEY_Ediaeresis: int = ...
KEY_Egrave: int = ...
KEY_Ehook: int = ...
KEY_Eisu_Shift: int = ...
KEY_Eisu_toggle: int = ...
KEY_Eject: int = ...
KEY_Emacron: int = ...
KEY_End: int = ...
KEY_Eogonek: int = ...
KEY_Escape: int = ...
KEY_Eth: int = ...
KEY_Etilde: int = ...
KEY_EuroSign: int = ...
KEY_Excel: int = ...
KEY_Execute: int = ...
KEY_Explorer: int = ...
KEY_F: int = ...
KEY_F1: int = ...
KEY_F10: int = ...
KEY_F11: int = ...
KEY_F12: int = ...
KEY_F13: int = ...
KEY_F14: int = ...
KEY_F15: int = ...
KEY_F16: int = ...
KEY_F17: int = ...
KEY_F18: int = ...
KEY_F19: int = ...
KEY_F2: int = ...
KEY_F20: int = ...
KEY_F21: int = ...
KEY_F22: int = ...
KEY_F23: int = ...
KEY_F24: int = ...
KEY_F25: int = ...
KEY_F26: int = ...
KEY_F27: int = ...
KEY_F28: int = ...
KEY_F29: int = ...
KEY_F3: int = ...
KEY_F30: int = ...
KEY_F31: int = ...
KEY_F32: int = ...
KEY_F33: int = ...
KEY_F34: int = ...
KEY_F35: int = ...
KEY_F4: int = ...
KEY_F5: int = ...
KEY_F6: int = ...
KEY_F7: int = ...
KEY_F8: int = ...
KEY_F9: int = ...
KEY_FFrancSign: int = ...
KEY_Fabovedot: int = ...
KEY_Farsi_0: int = ...
KEY_Farsi_1: int = ...
KEY_Farsi_2: int = ...
KEY_Farsi_3: int = ...
KEY_Farsi_4: int = ...
KEY_Farsi_5: int = ...
KEY_Farsi_6: int = ...
KEY_Farsi_7: int = ...
KEY_Farsi_8: int = ...
KEY_Farsi_9: int = ...
KEY_Farsi_yeh: int = ...
KEY_Favorites: int = ...
KEY_Finance: int = ...
KEY_Find: int = ...
KEY_First_Virtual_Screen: int = ...
KEY_Forward: int = ...
KEY_FrameBack: int = ...
KEY_FrameForward: int = ...
KEY_G: int = ...
KEY_Gabovedot: int = ...
KEY_Game: int = ...
KEY_Gbreve: int = ...
KEY_Gcaron: int = ...
KEY_Gcedilla: int = ...
KEY_Gcircumflex: int = ...
KEY_Georgian_an: int = ...
KEY_Georgian_ban: int = ...
KEY_Georgian_can: int = ...
KEY_Georgian_char: int = ...
KEY_Georgian_chin: int = ...
KEY_Georgian_cil: int = ...
KEY_Georgian_don: int = ...
KEY_Georgian_en: int = ...
KEY_Georgian_fi: int = ...
KEY_Georgian_gan: int = ...
KEY_Georgian_ghan: int = ...
KEY_Georgian_hae: int = ...
KEY_Georgian_har: int = ...
KEY_Georgian_he: int = ...
KEY_Georgian_hie: int = ...
KEY_Georgian_hoe: int = ...
KEY_Georgian_in: int = ...
KEY_Georgian_jhan: int = ...
KEY_Georgian_jil: int = ...
KEY_Georgian_kan: int = ...
KEY_Georgian_khar: int = ...
KEY_Georgian_las: int = ...
KEY_Georgian_man: int = ...
KEY_Georgian_nar: int = ...
KEY_Georgian_on: int = ...
KEY_Georgian_par: int = ...
KEY_Georgian_phar: int = ...
KEY_Georgian_qar: int = ...
KEY_Georgian_rae: int = ...
KEY_Georgian_san: int = ...
KEY_Georgian_shin: int = ...
KEY_Georgian_tan: int = ...
KEY_Georgian_tar: int = ...
KEY_Georgian_un: int = ...
KEY_Georgian_vin: int = ...
KEY_Georgian_we: int = ...
KEY_Georgian_xan: int = ...
KEY_Georgian_zen: int = ...
KEY_Georgian_zhar: int = ...
KEY_Go: int = ...
KEY_Greek_ALPHA: int = ...
KEY_Greek_ALPHAaccent: int = ...
KEY_Greek_BETA: int = ...
KEY_Greek_CHI: int = ...
KEY_Greek_DELTA: int = ...
KEY_Greek_EPSILON: int = ...
KEY_Greek_EPSILONaccent: int = ...
KEY_Greek_ETA: int = ...
KEY_Greek_ETAaccent: int = ...
KEY_Greek_GAMMA: int = ...
KEY_Greek_IOTA: int = ...
KEY_Greek_IOTAaccent: int = ...
KEY_Greek_IOTAdiaeresis: int = ...
KEY_Greek_IOTAdieresis: int = ...
KEY_Greek_KAPPA: int = ...
KEY_Greek_LAMBDA: int = ...
KEY_Greek_LAMDA: int = ...
KEY_Greek_MU: int = ...
KEY_Greek_NU: int = ...
KEY_Greek_OMEGA: int = ...
KEY_Greek_OMEGAaccent: int = ...
KEY_Greek_OMICRON: int = ...
KEY_Greek_OMICRONaccent: int = ...
KEY_Greek_PHI: int = ...
KEY_Greek_PI: int = ...
KEY_Greek_PSI: int = ...
KEY_Greek_RHO: int = ...
KEY_Greek_SIGMA: int = ...
KEY_Greek_TAU: int = ...
KEY_Greek_THETA: int = ...
KEY_Greek_UPSILON: int = ...
KEY_Greek_UPSILONaccent: int = ...
KEY_Greek_UPSILONdieresis: int = ...
KEY_Greek_XI: int = ...
KEY_Greek_ZETA: int = ...
KEY_Greek_accentdieresis: int = ...
KEY_Greek_alpha: int = ...
KEY_Greek_alphaaccent: int = ...
KEY_Greek_beta: int = ...
KEY_Greek_chi: int = ...
KEY_Greek_delta: int = ...
KEY_Greek_epsilon: int = ...
KEY_Greek_epsilonaccent: int = ...
KEY_Greek_eta: int = ...
KEY_Greek_etaaccent: int = ...
KEY_Greek_finalsmallsigma: int = ...
KEY_Greek_gamma: int = ...
KEY_Greek_horizbar: int = ...
KEY_Greek_iota: int = ...
KEY_Greek_iotaaccent: int = ...
KEY_Greek_iotaaccentdieresis: int = ...
KEY_Greek_iotadieresis: int = ...
KEY_Greek_kappa: int = ...
KEY_Greek_lambda: int = ...
KEY_Greek_lamda: int = ...
KEY_Greek_mu: int = ...
KEY_Greek_nu: int = ...
KEY_Greek_omega: int = ...
KEY_Greek_omegaaccent: int = ...
KEY_Greek_omicron: int = ...
KEY_Greek_omicronaccent: int = ...
KEY_Greek_phi: int = ...
KEY_Greek_pi: int = ...
KEY_Greek_psi: int = ...
KEY_Greek_rho: int = ...
KEY_Greek_sigma: int = ...
KEY_Greek_switch: int = ...
KEY_Greek_tau: int = ...
KEY_Greek_theta: int = ...
KEY_Greek_upsilon: int = ...
KEY_Greek_upsilonaccent: int = ...
KEY_Greek_upsilonaccentdieresis: int = ...
KEY_Greek_upsilondieresis: int = ...
KEY_Greek_xi: int = ...
KEY_Greek_zeta: int = ...
KEY_Green: int = ...
KEY_H: int = ...
KEY_Hangul: int = ...
KEY_Hangul_A: int = ...
KEY_Hangul_AE: int = ...
KEY_Hangul_AraeA: int = ...
KEY_Hangul_AraeAE: int = ...
KEY_Hangul_Banja: int = ...
KEY_Hangul_Cieuc: int = ...
KEY_Hangul_Codeinput: int = ...
KEY_Hangul_Dikeud: int = ...
KEY_Hangul_E: int = ...
KEY_Hangul_EO: int = ...
KEY_Hangul_EU: int = ...
KEY_Hangul_End: int = ...
KEY_Hangul_Hanja: int = ...
KEY_Hangul_Hieuh: int = ...
KEY_Hangul_I: int = ...
KEY_Hangul_Ieung: int = ...
KEY_Hangul_J_Cieuc: int = ...
KEY_Hangul_J_Dikeud: int = ...
KEY_Hangul_J_Hieuh: int = ...
KEY_Hangul_J_Ieung: int = ...
KEY_Hangul_J_Jieuj: int = ...
KEY_Hangul_J_Khieuq: int = ...
KEY_Hangul_J_Kiyeog: int = ...
KEY_Hangul_J_KiyeogSios: int = ...
KEY_Hangul_J_KkogjiDalrinIeung: int = ...
KEY_Hangul_J_Mieum: int = ...
KEY_Hangul_J_Nieun: int = ...
KEY_Hangul_J_NieunHieuh: int = ...
KEY_Hangul_J_NieunJieuj: int = ...
KEY_Hangul_J_PanSios: int = ...
KEY_Hangul_J_Phieuf: int = ...
KEY_Hangul_J_Pieub: int = ...
KEY_Hangul_J_PieubSios: int = ...
KEY_Hangul_J_Rieul: int = ...
KEY_Hangul_J_RieulHieuh: int = ...
KEY_Hangul_J_RieulKiyeog: int = ...
KEY_Hangul_J_RieulMieum: int = ...
KEY_Hangul_J_RieulPhieuf: int = ...
KEY_Hangul_J_RieulPieub: int = ...
KEY_Hangul_J_RieulSios: int = ...
KEY_Hangul_J_RieulTieut: int = ...
KEY_Hangul_J_Sios: int = ...
KEY_Hangul_J_SsangKiyeog: int = ...
KEY_Hangul_J_SsangSios: int = ...
KEY_Hangul_J_Tieut: int = ...
KEY_Hangul_J_YeorinHieuh: int = ...
KEY_Hangul_Jamo: int = ...
KEY_Hangul_Jeonja: int = ...
KEY_Hangul_Jieuj: int = ...
KEY_Hangul_Khieuq: int = ...
KEY_Hangul_Kiyeog: int = ...
KEY_Hangul_KiyeogSios: int = ...
KEY_Hangul_KkogjiDalrinIeung: int = ...
KEY_Hangul_Mieum: int = ...
KEY_Hangul_MultipleCandidate: int = ...
KEY_Hangul_Nieun: int = ...
KEY_Hangul_NieunHieuh: int = ...
KEY_Hangul_NieunJieuj: int = ...
KEY_Hangul_O: int = ...
KEY_Hangul_OE: int = ...
KEY_Hangul_PanSios: int = ...
KEY_Hangul_Phieuf: int = ...
KEY_Hangul_Pieub: int = ...
KEY_Hangul_PieubSios: int = ...
KEY_Hangul_PostHanja: int = ...
KEY_Hangul_PreHanja: int = ...
KEY_Hangul_PreviousCandidate: int = ...
KEY_Hangul_Rieul: int = ...
KEY_Hangul_RieulHieuh: int = ...
KEY_Hangul_RieulKiyeog: int = ...
KEY_Hangul_RieulMieum: int = ...
KEY_Hangul_RieulPhieuf: int = ...
KEY_Hangul_RieulPieub: int = ...
KEY_Hangul_RieulSios: int = ...
KEY_Hangul_RieulTieut: int = ...
KEY_Hangul_RieulYeorinHieuh: int = ...
KEY_Hangul_Romaja: int = ...
KEY_Hangul_SingleCandidate: int = ...
KEY_Hangul_Sios: int = ...
KEY_Hangul_Special: int = ...
KEY_Hangul_SsangDikeud: int = ...
KEY_Hangul_SsangJieuj: int = ...
KEY_Hangul_SsangKiyeog: int = ...
KEY_Hangul_SsangPieub: int = ...
KEY_Hangul_SsangSios: int = ...
KEY_Hangul_Start: int = ...
KEY_Hangul_SunkyeongeumMieum: int = ...
KEY_Hangul_SunkyeongeumPhieuf: int = ...
KEY_Hangul_SunkyeongeumPieub: int = ...
KEY_Hangul_Tieut: int = ...
KEY_Hangul_U: int = ...
KEY_Hangul_WA: int = ...
KEY_Hangul_WAE: int = ...
KEY_Hangul_WE: int = ...
KEY_Hangul_WEO: int = ...
KEY_Hangul_WI: int = ...
KEY_Hangul_YA: int = ...
KEY_Hangul_YAE: int = ...
KEY_Hangul_YE: int = ...
KEY_Hangul_YEO: int = ...
KEY_Hangul_YI: int = ...
KEY_Hangul_YO: int = ...
KEY_Hangul_YU: int = ...
KEY_Hangul_YeorinHieuh: int = ...
KEY_Hangul_switch: int = ...
KEY_Hankaku: int = ...
KEY_Hcircumflex: int = ...
KEY_Hebrew_switch: int = ...
KEY_Help: int = ...
KEY_Henkan: int = ...
KEY_Henkan_Mode: int = ...
KEY_Hibernate: int = ...
KEY_Hiragana: int = ...
KEY_Hiragana_Katakana: int = ...
KEY_History: int = ...
KEY_Home: int = ...
KEY_HomePage: int = ...
KEY_HotLinks: int = ...
KEY_Hstroke: int = ...
KEY_Hyper_L: int = ...
KEY_Hyper_R: int = ...
KEY_I: int = ...
KEY_ISO_Center_Object: int = ...
KEY_ISO_Continuous_Underline: int = ...
KEY_ISO_Discontinuous_Underline: int = ...
KEY_ISO_Emphasize: int = ...
KEY_ISO_Enter: int = ...
KEY_ISO_Fast_Cursor_Down: int = ...
KEY_ISO_Fast_Cursor_Left: int = ...
KEY_ISO_Fast_Cursor_Right: int = ...
KEY_ISO_Fast_Cursor_Up: int = ...
KEY_ISO_First_Group: int = ...
KEY_ISO_First_Group_Lock: int = ...
KEY_ISO_Group_Latch: int = ...
KEY_ISO_Group_Lock: int = ...
KEY_ISO_Group_Shift: int = ...
KEY_ISO_Last_Group: int = ...
KEY_ISO_Last_Group_Lock: int = ...
KEY_ISO_Left_Tab: int = ...
KEY_ISO_Level2_Latch: int = ...
KEY_ISO_Level3_Latch: int = ...
KEY_ISO_Level3_Lock: int = ...
KEY_ISO_Level3_Shift: int = ...
KEY_ISO_Level5_Latch: int = ...
KEY_ISO_Level5_Lock: int = ...
KEY_ISO_Level5_Shift: int = ...
KEY_ISO_Lock: int = ...
KEY_ISO_Move_Line_Down: int = ...
KEY_ISO_Move_Line_Up: int = ...
KEY_ISO_Next_Group: int = ...
KEY_ISO_Next_Group_Lock: int = ...
KEY_ISO_Partial_Line_Down: int = ...
KEY_ISO_Partial_Line_Up: int = ...
KEY_ISO_Partial_Space_Left: int = ...
KEY_ISO_Partial_Space_Right: int = ...
KEY_ISO_Prev_Group: int = ...
KEY_ISO_Prev_Group_Lock: int = ...
KEY_ISO_Release_Both_Margins: int = ...
KEY_ISO_Release_Margin_Left: int = ...
KEY_ISO_Release_Margin_Right: int = ...
KEY_ISO_Set_Margin_Left: int = ...
KEY_ISO_Set_Margin_Right: int = ...
KEY_Iabovedot: int = ...
KEY_Iacute: int = ...
KEY_Ibelowdot: int = ...
KEY_Ibreve: int = ...
KEY_Icircumflex: int = ...
KEY_Idiaeresis: int = ...
KEY_Igrave: int = ...
KEY_Ihook: int = ...
KEY_Imacron: int = ...
KEY_Insert: int = ...
KEY_Iogonek: int = ...
KEY_Itilde: int = ...
KEY_J: int = ...
KEY_Jcircumflex: int = ...
KEY_K: int = ...
KEY_KP_0: int = ...
KEY_KP_1: int = ...
KEY_KP_2: int = ...
KEY_KP_3: int = ...
KEY_KP_4: int = ...
KEY_KP_5: int = ...
KEY_KP_6: int = ...
KEY_KP_7: int = ...
KEY_KP_8: int = ...
KEY_KP_9: int = ...
KEY_KP_Add: int = ...
KEY_KP_Begin: int = ...
KEY_KP_Decimal: int = ...
KEY_KP_Delete: int = ...
KEY_KP_Divide: int = ...
KEY_KP_Down: int = ...
KEY_KP_End: int = ...
KEY_KP_Enter: int = ...
KEY_KP_Equal: int = ...
KEY_KP_F1: int = ...
KEY_KP_F2: int = ...
KEY_KP_F3: int = ...
KEY_KP_F4: int = ...
KEY_KP_Home: int = ...
KEY_KP_Insert: int = ...
KEY_KP_Left: int = ...
KEY_KP_Multiply: int = ...
KEY_KP_Next: int = ...
KEY_KP_Page_Down: int = ...
KEY_KP_Page_Up: int = ...
KEY_KP_Prior: int = ...
KEY_KP_Right: int = ...
KEY_KP_Separator: int = ...
KEY_KP_Space: int = ...
KEY_KP_Subtract: int = ...
KEY_KP_Tab: int = ...
KEY_KP_Up: int = ...
KEY_Kana_Lock: int = ...
KEY_Kana_Shift: int = ...
KEY_Kanji: int = ...
KEY_Kanji_Bangou: int = ...
KEY_Katakana: int = ...
KEY_KbdBrightnessDown: int = ...
KEY_KbdBrightnessUp: int = ...
KEY_KbdLightOnOff: int = ...
KEY_Kcedilla: int = ...
KEY_Keyboard: int = ...
KEY_Korean_Won: int = ...
KEY_L: int = ...
KEY_L1: int = ...
KEY_L10: int = ...
KEY_L2: int = ...
KEY_L3: int = ...
KEY_L4: int = ...
KEY_L5: int = ...
KEY_L6: int = ...
KEY_L7: int = ...
KEY_L8: int = ...
KEY_L9: int = ...
KEY_Lacute: int = ...
KEY_Last_Virtual_Screen: int = ...
KEY_Launch0: int = ...
KEY_Launch1: int = ...
KEY_Launch2: int = ...
KEY_Launch3: int = ...
KEY_Launch4: int = ...
KEY_Launch5: int = ...
KEY_Launch6: int = ...
KEY_Launch7: int = ...
KEY_Launch8: int = ...
KEY_Launch9: int = ...
KEY_LaunchA: int = ...
KEY_LaunchB: int = ...
KEY_LaunchC: int = ...
KEY_LaunchD: int = ...
KEY_LaunchE: int = ...
KEY_LaunchF: int = ...
KEY_Lbelowdot: int = ...
KEY_Lcaron: int = ...
KEY_Lcedilla: int = ...
KEY_Left: int = ...
KEY_LightBulb: int = ...
KEY_Linefeed: int = ...
KEY_LiraSign: int = ...
KEY_LogGrabInfo: int = ...
KEY_LogOff: int = ...
KEY_LogWindowTree: int = ...
KEY_Lstroke: int = ...
KEY_M: int = ...
KEY_Mabovedot: int = ...
KEY_Macedonia_DSE: int = ...
KEY_Macedonia_GJE: int = ...
KEY_Macedonia_KJE: int = ...
KEY_Macedonia_dse: int = ...
KEY_Macedonia_gje: int = ...
KEY_Macedonia_kje: int = ...
KEY_Mae_Koho: int = ...
KEY_Mail: int = ...
KEY_MailForward: int = ...
KEY_Market: int = ...
KEY_Massyo: int = ...
KEY_Meeting: int = ...
KEY_Memo: int = ...
KEY_Menu: int = ...
KEY_MenuKB: int = ...
KEY_MenuPB: int = ...
KEY_Messenger: int = ...
KEY_Meta_L: int = ...
KEY_Meta_R: int = ...
KEY_MillSign: int = ...
KEY_ModeLock: int = ...
KEY_Mode_switch: int = ...
KEY_MonBrightnessDown: int = ...
KEY_MonBrightnessUp: int = ...
KEY_MouseKeys_Accel_Enable: int = ...
KEY_MouseKeys_Enable: int = ...
KEY_Muhenkan: int = ...
KEY_Multi_key: int = ...
KEY_MultipleCandidate: int = ...
KEY_Music: int = ...
KEY_MyComputer: int = ...
KEY_MySites: int = ...
KEY_N: int = ...
KEY_Nacute: int = ...
KEY_NairaSign: int = ...
KEY_Ncaron: int = ...
KEY_Ncedilla: int = ...
KEY_New: int = ...
KEY_NewSheqelSign: int = ...
KEY_News: int = ...
KEY_Next: int = ...
KEY_Next_VMode: int = ...
KEY_Next_Virtual_Screen: int = ...
KEY_Ntilde: int = ...
KEY_Num_Lock: int = ...
KEY_O: int = ...
KEY_OE: int = ...
KEY_Oacute: int = ...
KEY_Obarred: int = ...
KEY_Obelowdot: int = ...
KEY_Ocaron: int = ...
KEY_Ocircumflex: int = ...
KEY_Ocircumflexacute: int = ...
KEY_Ocircumflexbelowdot: int = ...
KEY_Ocircumflexgrave: int = ...
KEY_Ocircumflexhook: int = ...
KEY_Ocircumflextilde: int = ...
KEY_Odiaeresis: int = ...
KEY_Odoubleacute: int = ...
KEY_OfficeHome: int = ...
KEY_Ograve: int = ...
KEY_Ohook: int = ...
KEY_Ohorn: int = ...
KEY_Ohornacute: int = ...
KEY_Ohornbelowdot: int = ...
KEY_Ohorngrave: int = ...
KEY_Ohornhook: int = ...
KEY_Ohorntilde: int = ...
KEY_Omacron: int = ...
KEY_Ooblique: int = ...
KEY_Open: int = ...
KEY_OpenURL: int = ...
KEY_Option: int = ...
KEY_Oslash: int = ...
KEY_Otilde: int = ...
KEY_Overlay1_Enable: int = ...
KEY_Overlay2_Enable: int = ...
KEY_P: int = ...
KEY_Pabovedot: int = ...
KEY_Page_Down: int = ...
KEY_Page_Up: int = ...
KEY_Paste: int = ...
KEY_Pause: int = ...
KEY_PesetaSign: int = ...
KEY_Phone: int = ...
KEY_Pictures: int = ...
KEY_Pointer_Accelerate: int = ...
KEY_Pointer_Button1: int = ...
KEY_Pointer_Button2: int = ...
KEY_Pointer_Button3: int = ...
KEY_Pointer_Button4: int = ...
KEY_Pointer_Button5: int = ...
KEY_Pointer_Button_Dflt: int = ...
KEY_Pointer_DblClick1: int = ...
KEY_Pointer_DblClick2: int = ...
KEY_Pointer_DblClick3: int = ...
KEY_Pointer_DblClick4: int = ...
KEY_Pointer_DblClick5: int = ...
KEY_Pointer_DblClick_Dflt: int = ...
KEY_Pointer_DfltBtnNext: int = ...
KEY_Pointer_DfltBtnPrev: int = ...
KEY_Pointer_Down: int = ...
KEY_Pointer_DownLeft: int = ...
KEY_Pointer_DownRight: int = ...
KEY_Pointer_Drag1: int = ...
KEY_Pointer_Drag2: int = ...
KEY_Pointer_Drag3: int = ...
KEY_Pointer_Drag4: int = ...
KEY_Pointer_Drag5: int = ...
KEY_Pointer_Drag_Dflt: int = ...
KEY_Pointer_EnableKeys: int = ...
KEY_Pointer_Left: int = ...
KEY_Pointer_Right: int = ...
KEY_Pointer_Up: int = ...
KEY_Pointer_UpLeft: int = ...
KEY_Pointer_UpRight: int = ...
KEY_PowerDown: int = ...
KEY_PowerOff: int = ...
KEY_Prev_VMode: int = ...
KEY_Prev_Virtual_Screen: int = ...
KEY_PreviousCandidate: int = ...
KEY_Print: int = ...
KEY_Prior: int = ...
KEY_Q: int = ...
KEY_R: int = ...
KEY_R1: int = ...
KEY_R10: int = ...
KEY_R11: int = ...
KEY_R12: int = ...
KEY_R13: int = ...
KEY_R14: int = ...
KEY_R15: int = ...
KEY_R2: int = ...
KEY_R3: int = ...
KEY_R4: int = ...
KEY_R5: int = ...
KEY_R6: int = ...
KEY_R7: int = ...
KEY_R8: int = ...
KEY_R9: int = ...
KEY_RFKill: int = ...
KEY_Racute: int = ...
KEY_Rcaron: int = ...
KEY_Rcedilla: int = ...
KEY_Red: int = ...
KEY_Redo: int = ...
KEY_Refresh: int = ...
KEY_Reload: int = ...
KEY_RepeatKeys_Enable: int = ...
KEY_Reply: int = ...
KEY_Return: int = ...
KEY_Right: int = ...
KEY_RockerDown: int = ...
KEY_RockerEnter: int = ...
KEY_RockerUp: int = ...
KEY_Romaji: int = ...
KEY_RotateWindows: int = ...
KEY_RotationKB: int = ...
KEY_RotationPB: int = ...
KEY_RupeeSign: int = ...
KEY_S: int = ...
KEY_SCHWA: int = ...
KEY_Sabovedot: int = ...
KEY_Sacute: int = ...
KEY_Save: int = ...
KEY_Scaron: int = ...
KEY_Scedilla: int = ...
KEY_Scircumflex: int = ...
KEY_ScreenSaver: int = ...
KEY_ScrollClick: int = ...
KEY_ScrollDown: int = ...
KEY_ScrollUp: int = ...
KEY_Scroll_Lock: int = ...
KEY_Search: int = ...
KEY_Select: int = ...
KEY_SelectButton: int = ...
KEY_Send: int = ...
KEY_Serbian_DJE: int = ...
KEY_Serbian_DZE: int = ...
KEY_Serbian_JE: int = ...
KEY_Serbian_LJE: int = ...
KEY_Serbian_NJE: int = ...
KEY_Serbian_TSHE: int = ...
KEY_Serbian_dje: int = ...
KEY_Serbian_dze: int = ...
KEY_Serbian_je: int = ...
KEY_Serbian_lje: int = ...
KEY_Serbian_nje: int = ...
KEY_Serbian_tshe: int = ...
KEY_Shift_L: int = ...
KEY_Shift_Lock: int = ...
KEY_Shift_R: int = ...
KEY_Shop: int = ...
KEY_SingleCandidate: int = ...
KEY_Sinh_a: int = ...
KEY_Sinh_aa: int = ...
KEY_Sinh_aa2: int = ...
KEY_Sinh_ae: int = ...
KEY_Sinh_ae2: int = ...
KEY_Sinh_aee: int = ...
KEY_Sinh_aee2: int = ...
KEY_Sinh_ai: int = ...
KEY_Sinh_ai2: int = ...
KEY_Sinh_al: int = ...
KEY_Sinh_au: int = ...
KEY_Sinh_au2: int = ...
KEY_Sinh_ba: int = ...
KEY_Sinh_bha: int = ...
KEY_Sinh_ca: int = ...
KEY_Sinh_cha: int = ...
KEY_Sinh_dda: int = ...
KEY_Sinh_ddha: int = ...
KEY_Sinh_dha: int = ...
KEY_Sinh_dhha: int = ...
KEY_Sinh_e: int = ...
KEY_Sinh_e2: int = ...
KEY_Sinh_ee: int = ...
KEY_Sinh_ee2: int = ...
KEY_Sinh_fa: int = ...
KEY_Sinh_ga: int = ...
KEY_Sinh_gha: int = ...
KEY_Sinh_h2: int = ...
KEY_Sinh_ha: int = ...
KEY_Sinh_i: int = ...
KEY_Sinh_i2: int = ...
KEY_Sinh_ii: int = ...
KEY_Sinh_ii2: int = ...
KEY_Sinh_ja: int = ...
KEY_Sinh_jha: int = ...
KEY_Sinh_jnya: int = ...
KEY_Sinh_ka: int = ...
KEY_Sinh_kha: int = ...
KEY_Sinh_kunddaliya: int = ...
KEY_Sinh_la: int = ...
KEY_Sinh_lla: int = ...
KEY_Sinh_lu: int = ...
KEY_Sinh_lu2: int = ...
KEY_Sinh_luu: int = ...
KEY_Sinh_luu2: int = ...
KEY_Sinh_ma: int = ...
KEY_Sinh_mba: int = ...
KEY_Sinh_na: int = ...
KEY_Sinh_ndda: int = ...
KEY_Sinh_ndha: int = ...
KEY_Sinh_ng: int = ...
KEY_Sinh_ng2: int = ...
KEY_Sinh_nga: int = ...
KEY_Sinh_nja: int = ...
KEY_Sinh_nna: int = ...
KEY_Sinh_nya: int = ...
KEY_Sinh_o: int = ...
KEY_Sinh_o2: int = ...
KEY_Sinh_oo: int = ...
KEY_Sinh_oo2: int = ...
KEY_Sinh_pa: int = ...
KEY_Sinh_pha: int = ...
KEY_Sinh_ra: int = ...
KEY_Sinh_ri: int = ...
KEY_Sinh_rii: int = ...
KEY_Sinh_ru2: int = ...
KEY_Sinh_ruu2: int = ...
KEY_Sinh_sa: int = ...
KEY_Sinh_sha: int = ...
KEY_Sinh_ssha: int = ...
KEY_Sinh_tha: int = ...
KEY_Sinh_thha: int = ...
KEY_Sinh_tta: int = ...
KEY_Sinh_ttha: int = ...
KEY_Sinh_u: int = ...
KEY_Sinh_u2: int = ...
KEY_Sinh_uu: int = ...
KEY_Sinh_uu2: int = ...
KEY_Sinh_va: int = ...
KEY_Sinh_ya: int = ...
KEY_Sleep: int = ...
KEY_SlowKeys_Enable: int = ...
KEY_Spell: int = ...
KEY_SplitScreen: int = ...
KEY_Standby: int = ...
KEY_Start: int = ...
KEY_StickyKeys_Enable: int = ...
KEY_Stop: int = ...
KEY_Subtitle: int = ...
KEY_Super_L: int = ...
KEY_Super_R: int = ...
KEY_Support: int = ...
KEY_Suspend: int = ...
KEY_Switch_VT_1: int = ...
KEY_Switch_VT_10: int = ...
KEY_Switch_VT_11: int = ...
KEY_Switch_VT_12: int = ...
KEY_Switch_VT_2: int = ...
KEY_Switch_VT_3: int = ...
KEY_Switch_VT_4: int = ...
KEY_Switch_VT_5: int = ...
KEY_Switch_VT_6: int = ...
KEY_Switch_VT_7: int = ...
KEY_Switch_VT_8: int = ...
KEY_Switch_VT_9: int = ...
KEY_Sys_Req: int = ...
KEY_T: int = ...
KEY_THORN: int = ...
KEY_Tab: int = ...
KEY_Tabovedot: int = ...
KEY_TaskPane: int = ...
KEY_Tcaron: int = ...
KEY_Tcedilla: int = ...
KEY_Terminal: int = ...
KEY_Terminate_Server: int = ...
KEY_Thai_baht: int = ...
KEY_Thai_bobaimai: int = ...
KEY_Thai_chochan: int = ...
KEY_Thai_chochang: int = ...
KEY_Thai_choching: int = ...
KEY_Thai_chochoe: int = ...
KEY_Thai_dochada: int = ...
KEY_Thai_dodek: int = ...
KEY_Thai_fofa: int = ...
KEY_Thai_fofan: int = ...
KEY_Thai_hohip: int = ...
KEY_Thai_honokhuk: int = ...
KEY_Thai_khokhai: int = ...
KEY_Thai_khokhon: int = ...
KEY_Thai_khokhuat: int = ...
KEY_Thai_khokhwai: int = ...
KEY_Thai_khorakhang: int = ...
KEY_Thai_kokai: int = ...
KEY_Thai_lakkhangyao: int = ...
KEY_Thai_lekchet: int = ...
KEY_Thai_lekha: int = ...
KEY_Thai_lekhok: int = ...
KEY_Thai_lekkao: int = ...
KEY_Thai_leknung: int = ...
KEY_Thai_lekpaet: int = ...
KEY_Thai_leksam: int = ...
KEY_Thai_leksi: int = ...
KEY_Thai_leksong: int = ...
KEY_Thai_leksun: int = ...
KEY_Thai_lochula: int = ...
KEY_Thai_loling: int = ...
KEY_Thai_lu: int = ...
KEY_Thai_maichattawa: int = ...
KEY_Thai_maiek: int = ...
KEY_Thai_maihanakat: int = ...
KEY_Thai_maihanakat_maitho: int = ...
KEY_Thai_maitaikhu: int = ...
KEY_Thai_maitho: int = ...
KEY_Thai_maitri: int = ...
KEY_Thai_maiyamok: int = ...
KEY_Thai_moma: int = ...
KEY_Thai_ngongu: int = ...
KEY_Thai_nikhahit: int = ...
KEY_Thai_nonen: int = ...
KEY_Thai_nonu: int = ...
KEY_Thai_oang: int = ...
KEY_Thai_paiyannoi: int = ...
KEY_Thai_phinthu: int = ...
KEY_Thai_phophan: int = ...
KEY_Thai_phophung: int = ...
KEY_Thai_phosamphao: int = ...
KEY_Thai_popla: int = ...
KEY_Thai_rorua: int = ...
KEY_Thai_ru: int = ...
KEY_Thai_saraa: int = ...
KEY_Thai_saraaa: int = ...
KEY_Thai_saraae: int = ...
KEY_Thai_saraaimaimalai: int = ...
KEY_Thai_saraaimaimuan: int = ...
KEY_Thai_saraam: int = ...
KEY_Thai_sarae: int = ...
KEY_Thai_sarai: int = ...
KEY_Thai_saraii: int = ...
KEY_Thai_sarao: int = ...
KEY_Thai_sarau: int = ...
KEY_Thai_saraue: int = ...
KEY_Thai_sarauee: int = ...
KEY_Thai_sarauu: int = ...
KEY_Thai_sorusi: int = ...
KEY_Thai_sosala: int = ...
KEY_Thai_soso: int = ...
KEY_Thai_sosua: int = ...
KEY_Thai_thanthakhat: int = ...
KEY_Thai_thonangmontho: int = ...
KEY_Thai_thophuthao: int = ...
KEY_Thai_thothahan: int = ...
KEY_Thai_thothan: int = ...
KEY_Thai_thothong: int = ...
KEY_Thai_thothung: int = ...
KEY_Thai_topatak: int = ...
KEY_Thai_totao: int = ...
KEY_Thai_wowaen: int = ...
KEY_Thai_yoyak: int = ...
KEY_Thai_yoying: int = ...
KEY_Thorn: int = ...
KEY_Time: int = ...
KEY_ToDoList: int = ...
KEY_Tools: int = ...
KEY_TopMenu: int = ...
KEY_TouchpadOff: int = ...
KEY_TouchpadOn: int = ...
KEY_TouchpadToggle: int = ...
KEY_Touroku: int = ...
KEY_Travel: int = ...
KEY_Tslash: int = ...
KEY_U: int = ...
KEY_UWB: int = ...
KEY_Uacute: int = ...
KEY_Ubelowdot: int = ...
KEY_Ubreve: int = ...
KEY_Ucircumflex: int = ...
KEY_Udiaeresis: int = ...
KEY_Udoubleacute: int = ...
KEY_Ugrave: int = ...
KEY_Uhook: int = ...
KEY_Uhorn: int = ...
KEY_Uhornacute: int = ...
KEY_Uhornbelowdot: int = ...
KEY_Uhorngrave: int = ...
KEY_Uhornhook: int = ...
KEY_Uhorntilde: int = ...
KEY_Ukrainian_GHE_WITH_UPTURN: int = ...
KEY_Ukrainian_I: int = ...
KEY_Ukrainian_IE: int = ...
KEY_Ukrainian_YI: int = ...
KEY_Ukrainian_ghe_with_upturn: int = ...
KEY_Ukrainian_i: int = ...
KEY_Ukrainian_ie: int = ...
KEY_Ukrainian_yi: int = ...
KEY_Ukranian_I: int = ...
KEY_Ukranian_JE: int = ...
KEY_Ukranian_YI: int = ...
KEY_Ukranian_i: int = ...
KEY_Ukranian_je: int = ...
KEY_Ukranian_yi: int = ...
KEY_Umacron: int = ...
KEY_Undo: int = ...
KEY_Ungrab: int = ...
KEY_Uogonek: int = ...
KEY_Up: int = ...
KEY_Uring: int = ...
KEY_User1KB: int = ...
KEY_User2KB: int = ...
KEY_UserPB: int = ...
KEY_Utilde: int = ...
KEY_V: int = ...
KEY_VendorHome: int = ...
KEY_Video: int = ...
KEY_View: int = ...
KEY_VoidSymbol: int = ...
KEY_W: int = ...
KEY_WLAN: int = ...
KEY_WWAN: int = ...
KEY_WWW: int = ...
KEY_Wacute: int = ...
KEY_WakeUp: int = ...
KEY_Wcircumflex: int = ...
KEY_Wdiaeresis: int = ...
KEY_WebCam: int = ...
KEY_Wgrave: int = ...
KEY_WheelButton: int = ...
KEY_WindowClear: int = ...
KEY_WonSign: int = ...
KEY_Word: int = ...
KEY_X: int = ...
KEY_Xabovedot: int = ...
KEY_Xfer: int = ...
KEY_Y: int = ...
KEY_Yacute: int = ...
KEY_Ybelowdot: int = ...
KEY_Ycircumflex: int = ...
KEY_Ydiaeresis: int = ...
KEY_Yellow: int = ...
KEY_Ygrave: int = ...
KEY_Yhook: int = ...
KEY_Ytilde: int = ...
KEY_Z: int = ...
KEY_Zabovedot: int = ...
KEY_Zacute: int = ...
KEY_Zcaron: int = ...
KEY_Zen_Koho: int = ...
KEY_Zenkaku: int = ...
KEY_Zenkaku_Hankaku: int = ...
KEY_ZoomIn: int = ...
KEY_ZoomOut: int = ...
KEY_Zstroke: int = ...
KEY_a: int = ...
KEY_aacute: int = ...
KEY_abelowdot: int = ...
KEY_abovedot: int = ...
KEY_abreve: int = ...
KEY_abreveacute: int = ...
KEY_abrevebelowdot: int = ...
KEY_abrevegrave: int = ...
KEY_abrevehook: int = ...
KEY_abrevetilde: int = ...
KEY_acircumflex: int = ...
KEY_acircumflexacute: int = ...
KEY_acircumflexbelowdot: int = ...
KEY_acircumflexgrave: int = ...
KEY_acircumflexhook: int = ...
KEY_acircumflextilde: int = ...
KEY_acute: int = ...
KEY_adiaeresis: int = ...
KEY_ae: int = ...
KEY_agrave: int = ...
KEY_ahook: int = ...
KEY_amacron: int = ...
KEY_ampersand: int = ...
KEY_aogonek: int = ...
KEY_apostrophe: int = ...
KEY_approxeq: int = ...
KEY_approximate: int = ...
KEY_aring: int = ...
KEY_asciicircum: int = ...
KEY_asciitilde: int = ...
KEY_asterisk: int = ...
KEY_at: int = ...
KEY_atilde: int = ...
KEY_b: int = ...
KEY_babovedot: int = ...
KEY_backslash: int = ...
KEY_ballotcross: int = ...
KEY_bar: int = ...
KEY_because: int = ...
KEY_blank: int = ...
KEY_botintegral: int = ...
KEY_botleftparens: int = ...
KEY_botleftsqbracket: int = ...
KEY_botleftsummation: int = ...
KEY_botrightparens: int = ...
KEY_botrightsqbracket: int = ...
KEY_botrightsummation: int = ...
KEY_bott: int = ...
KEY_botvertsummationconnector: int = ...
KEY_braceleft: int = ...
KEY_braceright: int = ...
KEY_bracketleft: int = ...
KEY_bracketright: int = ...
KEY_braille_blank: int = ...
KEY_braille_dot_1: int = ...
KEY_braille_dot_10: int = ...
KEY_braille_dot_2: int = ...
KEY_braille_dot_3: int = ...
KEY_braille_dot_4: int = ...
KEY_braille_dot_5: int = ...
KEY_braille_dot_6: int = ...
KEY_braille_dot_7: int = ...
KEY_braille_dot_8: int = ...
KEY_braille_dot_9: int = ...
KEY_braille_dots_1: int = ...
KEY_braille_dots_12: int = ...
KEY_braille_dots_123: int = ...
KEY_braille_dots_1234: int = ...
KEY_braille_dots_12345: int = ...
KEY_braille_dots_123456: int = ...
KEY_braille_dots_1234567: int = ...
KEY_braille_dots_12345678: int = ...
KEY_braille_dots_1234568: int = ...
KEY_braille_dots_123457: int = ...
KEY_braille_dots_1234578: int = ...
KEY_braille_dots_123458: int = ...
KEY_braille_dots_12346: int = ...
KEY_braille_dots_123467: int = ...
KEY_braille_dots_1234678: int = ...
KEY_braille_dots_123468: int = ...
KEY_braille_dots_12347: int = ...
KEY_braille_dots_123478: int = ...
KEY_braille_dots_12348: int = ...
KEY_braille_dots_1235: int = ...
KEY_braille_dots_12356: int = ...
KEY_braille_dots_123567: int = ...
KEY_braille_dots_1235678: int = ...
KEY_braille_dots_123568: int = ...
KEY_braille_dots_12357: int = ...
KEY_braille_dots_123578: int = ...
KEY_braille_dots_12358: int = ...
KEY_braille_dots_1236: int = ...
KEY_braille_dots_12367: int = ...
KEY_braille_dots_123678: int = ...
KEY_braille_dots_12368: int = ...
KEY_braille_dots_1237: int = ...
KEY_braille_dots_12378: int = ...
KEY_braille_dots_1238: int = ...
KEY_braille_dots_124: int = ...
KEY_braille_dots_1245: int = ...
KEY_braille_dots_12456: int = ...
KEY_braille_dots_124567: int = ...
KEY_braille_dots_1245678: int = ...
KEY_braille_dots_124568: int = ...
KEY_braille_dots_12457: int = ...
KEY_braille_dots_124578: int = ...
KEY_braille_dots_12458: int = ...
KEY_braille_dots_1246: int = ...
KEY_braille_dots_12467: int = ...
KEY_braille_dots_124678: int = ...
KEY_braille_dots_12468: int = ...
KEY_braille_dots_1247: int = ...
KEY_braille_dots_12478: int = ...
KEY_braille_dots_1248: int = ...
KEY_braille_dots_125: int = ...
KEY_braille_dots_1256: int = ...
KEY_braille_dots_12567: int = ...
KEY_braille_dots_125678: int = ...
KEY_braille_dots_12568: int = ...
KEY_braille_dots_1257: int = ...
KEY_braille_dots_12578: int = ...
KEY_braille_dots_1258: int = ...
KEY_braille_dots_126: int = ...
KEY_braille_dots_1267: int = ...
KEY_braille_dots_12678: int = ...
KEY_braille_dots_1268: int = ...
KEY_braille_dots_127: int = ...
KEY_braille_dots_1278: int = ...
KEY_braille_dots_128: int = ...
KEY_braille_dots_13: int = ...
KEY_braille_dots_134: int = ...
KEY_braille_dots_1345: int = ...
KEY_braille_dots_13456: int = ...
KEY_braille_dots_134567: int = ...
KEY_braille_dots_1345678: int = ...
KEY_braille_dots_134568: int = ...
KEY_braille_dots_13457: int = ...
KEY_braille_dots_134578: int = ...
KEY_braille_dots_13458: int = ...
KEY_braille_dots_1346: int = ...
KEY_braille_dots_13467: int = ...
KEY_braille_dots_134678: int = ...
KEY_braille_dots_13468: int = ...
KEY_braille_dots_1347: int = ...
KEY_braille_dots_13478: int = ...
KEY_braille_dots_1348: int = ...
KEY_braille_dots_135: int = ...
KEY_braille_dots_1356: int = ...
KEY_braille_dots_13567: int = ...
KEY_braille_dots_135678: int = ...
KEY_braille_dots_13568: int = ...
KEY_braille_dots_1357: int = ...
KEY_braille_dots_13578: int = ...
KEY_braille_dots_1358: int = ...
KEY_braille_dots_136: int = ...
KEY_braille_dots_1367: int = ...
KEY_braille_dots_13678: int = ...
KEY_braille_dots_1368: int = ...
KEY_braille_dots_137: int = ...
KEY_braille_dots_1378: int = ...
KEY_braille_dots_138: int = ...
KEY_braille_dots_14: int = ...
KEY_braille_dots_145: int = ...
KEY_braille_dots_1456: int = ...
KEY_braille_dots_14567: int = ...
KEY_braille_dots_145678: int = ...
KEY_braille_dots_14568: int = ...
KEY_braille_dots_1457: int = ...
KEY_braille_dots_14578: int = ...
KEY_braille_dots_1458: int = ...
KEY_braille_dots_146: int = ...
KEY_braille_dots_1467: int = ...
KEY_braille_dots_14678: int = ...
KEY_braille_dots_1468: int = ...
KEY_braille_dots_147: int = ...
KEY_braille_dots_1478: int = ...
KEY_braille_dots_148: int = ...
KEY_braille_dots_15: int = ...
KEY_braille_dots_156: int = ...
KEY_braille_dots_1567: int = ...
KEY_braille_dots_15678: int = ...
KEY_braille_dots_1568: int = ...
KEY_braille_dots_157: int = ...
KEY_braille_dots_1578: int = ...
KEY_braille_dots_158: int = ...
KEY_braille_dots_16: int = ...
KEY_braille_dots_167: int = ...
KEY_braille_dots_1678: int = ...
KEY_braille_dots_168: int = ...
KEY_braille_dots_17: int = ...
KEY_braille_dots_178: int = ...
KEY_braille_dots_18: int = ...
KEY_braille_dots_2: int = ...
KEY_braille_dots_23: int = ...
KEY_braille_dots_234: int = ...
KEY_braille_dots_2345: int = ...
KEY_braille_dots_23456: int = ...
KEY_braille_dots_234567: int = ...
KEY_braille_dots_2345678: int = ...
KEY_braille_dots_234568: int = ...
KEY_braille_dots_23457: int = ...
KEY_braille_dots_234578: int = ...
KEY_braille_dots_23458: int = ...
KEY_braille_dots_2346: int = ...
KEY_braille_dots_23467: int = ...
KEY_braille_dots_234678: int = ...
KEY_braille_dots_23468: int = ...
KEY_braille_dots_2347: int = ...
KEY_braille_dots_23478: int = ...
KEY_braille_dots_2348: int = ...
KEY_braille_dots_235: int = ...
KEY_braille_dots_2356: int = ...
KEY_braille_dots_23567: int = ...
KEY_braille_dots_235678: int = ...
KEY_braille_dots_23568: int = ...
KEY_braille_dots_2357: int = ...
KEY_braille_dots_23578: int = ...
KEY_braille_dots_2358: int = ...
KEY_braille_dots_236: int = ...
KEY_braille_dots_2367: int = ...
KEY_braille_dots_23678: int = ...
KEY_braille_dots_2368: int = ...
KEY_braille_dots_237: int = ...
KEY_braille_dots_2378: int = ...
KEY_braille_dots_238: int = ...
KEY_braille_dots_24: int = ...
KEY_braille_dots_245: int = ...
KEY_braille_dots_2456: int = ...
KEY_braille_dots_24567: int = ...
KEY_braille_dots_245678: int = ...
KEY_braille_dots_24568: int = ...
KEY_braille_dots_2457: int = ...
KEY_braille_dots_24578: int = ...
KEY_braille_dots_2458: int = ...
KEY_braille_dots_246: int = ...
KEY_braille_dots_2467: int = ...
KEY_braille_dots_24678: int = ...
KEY_braille_dots_2468: int = ...
KEY_braille_dots_247: int = ...
KEY_braille_dots_2478: int = ...
KEY_braille_dots_248: int = ...
KEY_braille_dots_25: int = ...
KEY_braille_dots_256: int = ...
KEY_braille_dots_2567: int = ...
KEY_braille_dots_25678: int = ...
KEY_braille_dots_2568: int = ...
KEY_braille_dots_257: int = ...
KEY_braille_dots_2578: int = ...
KEY_braille_dots_258: int = ...
KEY_braille_dots_26: int = ...
KEY_braille_dots_267: int = ...
KEY_braille_dots_2678: int = ...
KEY_braille_dots_268: int = ...
KEY_braille_dots_27: int = ...
KEY_braille_dots_278: int = ...
KEY_braille_dots_28: int = ...
KEY_braille_dots_3: int = ...
KEY_braille_dots_34: int = ...
KEY_braille_dots_345: int = ...
KEY_braille_dots_3456: int = ...
KEY_braille_dots_34567: int = ...
KEY_braille_dots_345678: int = ...
KEY_braille_dots_34568: int = ...
KEY_braille_dots_3457: int = ...
KEY_braille_dots_34578: int = ...
KEY_braille_dots_3458: int = ...
KEY_braille_dots_346: int = ...
KEY_braille_dots_3467: int = ...
KEY_braille_dots_34678: int = ...
KEY_braille_dots_3468: int = ...
KEY_braille_dots_347: int = ...
KEY_braille_dots_3478: int = ...
KEY_braille_dots_348: int = ...
KEY_braille_dots_35: int = ...
KEY_braille_dots_356: int = ...
KEY_braille_dots_3567: int = ...
KEY_braille_dots_35678: int = ...
KEY_braille_dots_3568: int = ...
KEY_braille_dots_357: int = ...
KEY_braille_dots_3578: int = ...
KEY_braille_dots_358: int = ...
KEY_braille_dots_36: int = ...
KEY_braille_dots_367: int = ...
KEY_braille_dots_3678: int = ...
KEY_braille_dots_368: int = ...
KEY_braille_dots_37: int = ...
KEY_braille_dots_378: int = ...
KEY_braille_dots_38: int = ...
KEY_braille_dots_4: int = ...
KEY_braille_dots_45: int = ...
KEY_braille_dots_456: int = ...
KEY_braille_dots_4567: int = ...
KEY_braille_dots_45678: int = ...
KEY_braille_dots_4568: int = ...
KEY_braille_dots_457: int = ...
KEY_braille_dots_4578: int = ...
KEY_braille_dots_458: int = ...
KEY_braille_dots_46: int = ...
KEY_braille_dots_467: int = ...
KEY_braille_dots_4678: int = ...
KEY_braille_dots_468: int = ...
KEY_braille_dots_47: int = ...
KEY_braille_dots_478: int = ...
KEY_braille_dots_48: int = ...
KEY_braille_dots_5: int = ...
KEY_braille_dots_56: int = ...
KEY_braille_dots_567: int = ...
KEY_braille_dots_5678: int = ...
KEY_braille_dots_568: int = ...
KEY_braille_dots_57: int = ...
KEY_braille_dots_578: int = ...
KEY_braille_dots_58: int = ...
KEY_braille_dots_6: int = ...
KEY_braille_dots_67: int = ...
KEY_braille_dots_678: int = ...
KEY_braille_dots_68: int = ...
KEY_braille_dots_7: int = ...
KEY_braille_dots_78: int = ...
KEY_braille_dots_8: int = ...
KEY_breve: int = ...
KEY_brokenbar: int = ...
KEY_c: int = ...
KEY_c_h: int = ...
KEY_cabovedot: int = ...
KEY_cacute: int = ...
KEY_careof: int = ...
KEY_caret: int = ...
KEY_caron: int = ...
KEY_ccaron: int = ...
KEY_ccedilla: int = ...
KEY_ccircumflex: int = ...
KEY_cedilla: int = ...
KEY_cent: int = ...
KEY_ch: int = ...
KEY_checkerboard: int = ...
KEY_checkmark: int = ...
KEY_circle: int = ...
KEY_club: int = ...
KEY_colon: int = ...
KEY_comma: int = ...
KEY_containsas: int = ...
KEY_copyright: int = ...
KEY_cr: int = ...
KEY_crossinglines: int = ...
KEY_cuberoot: int = ...
KEY_currency: int = ...
KEY_cursor: int = ...
KEY_d: int = ...
KEY_dabovedot: int = ...
KEY_dagger: int = ...
KEY_dcaron: int = ...
KEY_dead_A: int = ...
KEY_dead_E: int = ...
KEY_dead_I: int = ...
KEY_dead_O: int = ...
KEY_dead_U: int = ...
KEY_dead_a: int = ...
KEY_dead_abovecomma: int = ...
KEY_dead_abovedot: int = ...
KEY_dead_abovereversedcomma: int = ...
KEY_dead_abovering: int = ...
KEY_dead_aboveverticalline: int = ...
KEY_dead_acute: int = ...
KEY_dead_belowbreve: int = ...
KEY_dead_belowcircumflex: int = ...
KEY_dead_belowcomma: int = ...
KEY_dead_belowdiaeresis: int = ...
KEY_dead_belowdot: int = ...
KEY_dead_belowmacron: int = ...
KEY_dead_belowring: int = ...
KEY_dead_belowtilde: int = ...
KEY_dead_belowverticalline: int = ...
KEY_dead_breve: int = ...
KEY_dead_capital_schwa: int = ...
KEY_dead_caron: int = ...
KEY_dead_cedilla: int = ...
KEY_dead_circumflex: int = ...
KEY_dead_currency: int = ...
KEY_dead_dasia: int = ...
KEY_dead_diaeresis: int = ...
KEY_dead_doubleacute: int = ...
KEY_dead_doublegrave: int = ...
KEY_dead_e: int = ...
KEY_dead_grave: int = ...
KEY_dead_greek: int = ...
KEY_dead_hook: int = ...
KEY_dead_horn: int = ...
KEY_dead_i: int = ...
KEY_dead_invertedbreve: int = ...
KEY_dead_iota: int = ...
KEY_dead_longsolidusoverlay: int = ...
KEY_dead_lowline: int = ...
KEY_dead_macron: int = ...
KEY_dead_o: int = ...
KEY_dead_ogonek: int = ...
KEY_dead_perispomeni: int = ...
KEY_dead_psili: int = ...
KEY_dead_semivoiced_sound: int = ...
KEY_dead_small_schwa: int = ...
KEY_dead_stroke: int = ...
KEY_dead_tilde: int = ...
KEY_dead_u: int = ...
KEY_dead_voiced_sound: int = ...
KEY_decimalpoint: int = ...
KEY_degree: int = ...
KEY_diaeresis: int = ...
KEY_diamond: int = ...
KEY_digitspace: int = ...
KEY_dintegral: int = ...
KEY_division: int = ...
KEY_dollar: int = ...
KEY_doubbaselinedot: int = ...
KEY_doubleacute: int = ...
KEY_doubledagger: int = ...
KEY_doublelowquotemark: int = ...
KEY_downarrow: int = ...
KEY_downcaret: int = ...
KEY_downshoe: int = ...
KEY_downstile: int = ...
KEY_downtack: int = ...
KEY_dstroke: int = ...
KEY_e: int = ...
KEY_eabovedot: int = ...
KEY_eacute: int = ...
KEY_ebelowdot: int = ...
KEY_ecaron: int = ...
KEY_ecircumflex: int = ...
KEY_ecircumflexacute: int = ...
KEY_ecircumflexbelowdot: int = ...
KEY_ecircumflexgrave: int = ...
KEY_ecircumflexhook: int = ...
KEY_ecircumflextilde: int = ...
KEY_ediaeresis: int = ...
KEY_egrave: int = ...
KEY_ehook: int = ...
KEY_eightsubscript: int = ...
KEY_eightsuperior: int = ...
KEY_elementof: int = ...
KEY_ellipsis: int = ...
KEY_em3space: int = ...
KEY_em4space: int = ...
KEY_emacron: int = ...
KEY_emdash: int = ...
KEY_emfilledcircle: int = ...
KEY_emfilledrect: int = ...
KEY_emopencircle: int = ...
KEY_emopenrectangle: int = ...
KEY_emptyset: int = ...
KEY_emspace: int = ...
KEY_endash: int = ...
KEY_enfilledcircbullet: int = ...
KEY_enfilledsqbullet: int = ...
KEY_eng: int = ...
KEY_enopencircbullet: int = ...
KEY_enopensquarebullet: int = ...
KEY_enspace: int = ...
KEY_eogonek: int = ...
KEY_equal: int = ...
KEY_eth: int = ...
KEY_etilde: int = ...
KEY_exclam: int = ...
KEY_exclamdown: int = ...
KEY_ezh: int = ...
KEY_f: int = ...
KEY_fabovedot: int = ...
KEY_femalesymbol: int = ...
KEY_ff: int = ...
KEY_figdash: int = ...
KEY_filledlefttribullet: int = ...
KEY_filledrectbullet: int = ...
KEY_filledrighttribullet: int = ...
KEY_filledtribulletdown: int = ...
KEY_filledtribulletup: int = ...
KEY_fiveeighths: int = ...
KEY_fivesixths: int = ...
KEY_fivesubscript: int = ...
KEY_fivesuperior: int = ...
KEY_fourfifths: int = ...
KEY_foursubscript: int = ...
KEY_foursuperior: int = ...
KEY_fourthroot: int = ...
KEY_function: int = ...
KEY_g: int = ...
KEY_gabovedot: int = ...
KEY_gbreve: int = ...
KEY_gcaron: int = ...
KEY_gcedilla: int = ...
KEY_gcircumflex: int = ...
KEY_grave: int = ...
KEY_greater: int = ...
KEY_greaterthanequal: int = ...
KEY_guillemotleft: int = ...
KEY_guillemotright: int = ...
KEY_h: int = ...
KEY_hairspace: int = ...
KEY_hcircumflex: int = ...
KEY_heart: int = ...
KEY_hebrew_aleph: int = ...
KEY_hebrew_ayin: int = ...
KEY_hebrew_bet: int = ...
KEY_hebrew_beth: int = ...
KEY_hebrew_chet: int = ...
KEY_hebrew_dalet: int = ...
KEY_hebrew_daleth: int = ...
KEY_hebrew_doublelowline: int = ...
KEY_hebrew_finalkaph: int = ...
KEY_hebrew_finalmem: int = ...
KEY_hebrew_finalnun: int = ...
KEY_hebrew_finalpe: int = ...
KEY_hebrew_finalzade: int = ...
KEY_hebrew_finalzadi: int = ...
KEY_hebrew_gimel: int = ...
KEY_hebrew_gimmel: int = ...
KEY_hebrew_he: int = ...
KEY_hebrew_het: int = ...
KEY_hebrew_kaph: int = ...
KEY_hebrew_kuf: int = ...
KEY_hebrew_lamed: int = ...
KEY_hebrew_mem: int = ...
KEY_hebrew_nun: int = ...
KEY_hebrew_pe: int = ...
KEY_hebrew_qoph: int = ...
KEY_hebrew_resh: int = ...
KEY_hebrew_samech: int = ...
KEY_hebrew_samekh: int = ...
KEY_hebrew_shin: int = ...
KEY_hebrew_taf: int = ...
KEY_hebrew_taw: int = ...
KEY_hebrew_tet: int = ...
KEY_hebrew_teth: int = ...
KEY_hebrew_waw: int = ...
KEY_hebrew_yod: int = ...
KEY_hebrew_zade: int = ...
KEY_hebrew_zadi: int = ...
KEY_hebrew_zain: int = ...
KEY_hebrew_zayin: int = ...
KEY_hexagram: int = ...
KEY_horizconnector: int = ...
KEY_horizlinescan1: int = ...
KEY_horizlinescan3: int = ...
KEY_horizlinescan5: int = ...
KEY_horizlinescan7: int = ...
KEY_horizlinescan9: int = ...
KEY_hstroke: int = ...
KEY_ht: int = ...
KEY_hyphen: int = ...
KEY_i: int = ...
KEY_iTouch: int = ...
KEY_iacute: int = ...
KEY_ibelowdot: int = ...
KEY_ibreve: int = ...
KEY_icircumflex: int = ...
KEY_identical: int = ...
KEY_idiaeresis: int = ...
KEY_idotless: int = ...
KEY_ifonlyif: int = ...
KEY_igrave: int = ...
KEY_ihook: int = ...
KEY_imacron: int = ...
KEY_implies: int = ...
KEY_includedin: int = ...
KEY_includes: int = ...
KEY_infinity: int = ...
KEY_integral: int = ...
KEY_intersection: int = ...
KEY_iogonek: int = ...
KEY_itilde: int = ...
KEY_j: int = ...
KEY_jcircumflex: int = ...
KEY_jot: int = ...
KEY_k: int = ...
KEY_kana_A: int = ...
KEY_kana_CHI: int = ...
KEY_kana_E: int = ...
KEY_kana_FU: int = ...
KEY_kana_HA: int = ...
KEY_kana_HE: int = ...
KEY_kana_HI: int = ...
KEY_kana_HO: int = ...
KEY_kana_HU: int = ...
KEY_kana_I: int = ...
KEY_kana_KA: int = ...
KEY_kana_KE: int = ...
KEY_kana_KI: int = ...
KEY_kana_KO: int = ...
KEY_kana_KU: int = ...
KEY_kana_MA: int = ...
KEY_kana_ME: int = ...
KEY_kana_MI: int = ...
KEY_kana_MO: int = ...
KEY_kana_MU: int = ...
KEY_kana_N: int = ...
KEY_kana_NA: int = ...
KEY_kana_NE: int = ...
KEY_kana_NI: int = ...
KEY_kana_NO: int = ...
KEY_kana_NU: int = ...
KEY_kana_O: int = ...
KEY_kana_RA: int = ...
KEY_kana_RE: int = ...
KEY_kana_RI: int = ...
KEY_kana_RO: int = ...
KEY_kana_RU: int = ...
KEY_kana_SA: int = ...
KEY_kana_SE: int = ...
KEY_kana_SHI: int = ...
KEY_kana_SO: int = ...
KEY_kana_SU: int = ...
KEY_kana_TA: int = ...
KEY_kana_TE: int = ...
KEY_kana_TI: int = ...
KEY_kana_TO: int = ...
KEY_kana_TSU: int = ...
KEY_kana_TU: int = ...
KEY_kana_U: int = ...
KEY_kana_WA: int = ...
KEY_kana_WO: int = ...
KEY_kana_YA: int = ...
KEY_kana_YO: int = ...
KEY_kana_YU: int = ...
KEY_kana_a: int = ...
KEY_kana_closingbracket: int = ...
KEY_kana_comma: int = ...
KEY_kana_conjunctive: int = ...
KEY_kana_e: int = ...
KEY_kana_fullstop: int = ...
KEY_kana_i: int = ...
KEY_kana_middledot: int = ...
KEY_kana_o: int = ...
KEY_kana_openingbracket: int = ...
KEY_kana_switch: int = ...
KEY_kana_tsu: int = ...
KEY_kana_tu: int = ...
KEY_kana_u: int = ...
KEY_kana_ya: int = ...
KEY_kana_yo: int = ...
KEY_kana_yu: int = ...
KEY_kappa: int = ...
KEY_kcedilla: int = ...
KEY_kra: int = ...
KEY_l: int = ...
KEY_lacute: int = ...
KEY_latincross: int = ...
KEY_lbelowdot: int = ...
KEY_lcaron: int = ...
KEY_lcedilla: int = ...
KEY_leftanglebracket: int = ...
KEY_leftarrow: int = ...
KEY_leftcaret: int = ...
KEY_leftdoublequotemark: int = ...
KEY_leftmiddlecurlybrace: int = ...
KEY_leftopentriangle: int = ...
KEY_leftpointer: int = ...
KEY_leftradical: int = ...
KEY_leftshoe: int = ...
KEY_leftsinglequotemark: int = ...
KEY_leftt: int = ...
KEY_lefttack: int = ...
KEY_less: int = ...
KEY_lessthanequal: int = ...
KEY_lf: int = ...
KEY_logicaland: int = ...
KEY_logicalor: int = ...
KEY_lowleftcorner: int = ...
KEY_lowrightcorner: int = ...
KEY_lstroke: int = ...
KEY_m: int = ...
KEY_mabovedot: int = ...
KEY_macron: int = ...
KEY_malesymbol: int = ...
KEY_maltesecross: int = ...
KEY_marker: int = ...
KEY_masculine: int = ...
KEY_minus: int = ...
KEY_minutes: int = ...
KEY_mu: int = ...
KEY_multiply: int = ...
KEY_musicalflat: int = ...
KEY_musicalsharp: int = ...
KEY_n: int = ...
KEY_nabla: int = ...
KEY_nacute: int = ...
KEY_ncaron: int = ...
KEY_ncedilla: int = ...
KEY_ninesubscript: int = ...
KEY_ninesuperior: int = ...
KEY_nl: int = ...
KEY_nobreakspace: int = ...
KEY_notapproxeq: int = ...
KEY_notelementof: int = ...
KEY_notequal: int = ...
KEY_notidentical: int = ...
KEY_notsign: int = ...
KEY_ntilde: int = ...
KEY_numbersign: int = ...
KEY_numerosign: int = ...
KEY_o: int = ...
KEY_oacute: int = ...
KEY_obarred: int = ...
KEY_obelowdot: int = ...
KEY_ocaron: int = ...
KEY_ocircumflex: int = ...
KEY_ocircumflexacute: int = ...
KEY_ocircumflexbelowdot: int = ...
KEY_ocircumflexgrave: int = ...
KEY_ocircumflexhook: int = ...
KEY_ocircumflextilde: int = ...
KEY_odiaeresis: int = ...
KEY_odoubleacute: int = ...
KEY_oe: int = ...
KEY_ogonek: int = ...
KEY_ograve: int = ...
KEY_ohook: int = ...
KEY_ohorn: int = ...
KEY_ohornacute: int = ...
KEY_ohornbelowdot: int = ...
KEY_ohorngrave: int = ...
KEY_ohornhook: int = ...
KEY_ohorntilde: int = ...
KEY_omacron: int = ...
KEY_oneeighth: int = ...
KEY_onefifth: int = ...
KEY_onehalf: int = ...
KEY_onequarter: int = ...
KEY_onesixth: int = ...
KEY_onesubscript: int = ...
KEY_onesuperior: int = ...
KEY_onethird: int = ...
KEY_ooblique: int = ...
KEY_openrectbullet: int = ...
KEY_openstar: int = ...
KEY_opentribulletdown: int = ...
KEY_opentribulletup: int = ...
KEY_ordfeminine: int = ...
KEY_oslash: int = ...
KEY_otilde: int = ...
KEY_overbar: int = ...
KEY_overline: int = ...
KEY_p: int = ...
KEY_pabovedot: int = ...
KEY_paragraph: int = ...
KEY_parenleft: int = ...
KEY_parenright: int = ...
KEY_partdifferential: int = ...
KEY_partialderivative: int = ...
KEY_percent: int = ...
KEY_period: int = ...
KEY_periodcentered: int = ...
KEY_permille: int = ...
KEY_phonographcopyright: int = ...
KEY_plus: int = ...
KEY_plusminus: int = ...
KEY_prescription: int = ...
KEY_prolongedsound: int = ...
KEY_punctspace: int = ...
KEY_q: int = ...
KEY_quad: int = ...
KEY_question: int = ...
KEY_questiondown: int = ...
KEY_quotedbl: int = ...
KEY_quoteleft: int = ...
KEY_quoteright: int = ...
KEY_r: int = ...
KEY_racute: int = ...
KEY_radical: int = ...
KEY_rcaron: int = ...
KEY_rcedilla: int = ...
KEY_registered: int = ...
KEY_rightanglebracket: int = ...
KEY_rightarrow: int = ...
KEY_rightcaret: int = ...
KEY_rightdoublequotemark: int = ...
KEY_rightmiddlecurlybrace: int = ...
KEY_rightmiddlesummation: int = ...
KEY_rightopentriangle: int = ...
KEY_rightpointer: int = ...
KEY_rightshoe: int = ...
KEY_rightsinglequotemark: int = ...
KEY_rightt: int = ...
KEY_righttack: int = ...
KEY_s: int = ...
KEY_sabovedot: int = ...
KEY_sacute: int = ...
KEY_scaron: int = ...
KEY_scedilla: int = ...
KEY_schwa: int = ...
KEY_scircumflex: int = ...
KEY_script_switch: int = ...
KEY_seconds: int = ...
KEY_section: int = ...
KEY_semicolon: int = ...
KEY_semivoicedsound: int = ...
KEY_seveneighths: int = ...
KEY_sevensubscript: int = ...
KEY_sevensuperior: int = ...
KEY_signaturemark: int = ...
KEY_signifblank: int = ...
KEY_similarequal: int = ...
KEY_singlelowquotemark: int = ...
KEY_sixsubscript: int = ...
KEY_sixsuperior: int = ...
KEY_slash: int = ...
KEY_soliddiamond: int = ...
KEY_space: int = ...
KEY_squareroot: int = ...
KEY_ssharp: int = ...
KEY_sterling: int = ...
KEY_stricteq: int = ...
KEY_t: int = ...
KEY_tabovedot: int = ...
KEY_tcaron: int = ...
KEY_tcedilla: int = ...
KEY_telephone: int = ...
KEY_telephonerecorder: int = ...
KEY_therefore: int = ...
KEY_thinspace: int = ...
KEY_thorn: int = ...
KEY_threeeighths: int = ...
KEY_threefifths: int = ...
KEY_threequarters: int = ...
KEY_threesubscript: int = ...
KEY_threesuperior: int = ...
KEY_tintegral: int = ...
KEY_topintegral: int = ...
KEY_topleftparens: int = ...
KEY_topleftradical: int = ...
KEY_topleftsqbracket: int = ...
KEY_topleftsummation: int = ...
KEY_toprightparens: int = ...
KEY_toprightsqbracket: int = ...
KEY_toprightsummation: int = ...
KEY_topt: int = ...
KEY_topvertsummationconnector: int = ...
KEY_trademark: int = ...
KEY_trademarkincircle: int = ...
KEY_tslash: int = ...
KEY_twofifths: int = ...
KEY_twosubscript: int = ...
KEY_twosuperior: int = ...
KEY_twothirds: int = ...
KEY_u: int = ...
KEY_uacute: int = ...
KEY_ubelowdot: int = ...
KEY_ubreve: int = ...
KEY_ucircumflex: int = ...
KEY_udiaeresis: int = ...
KEY_udoubleacute: int = ...
KEY_ugrave: int = ...
KEY_uhook: int = ...
KEY_uhorn: int = ...
KEY_uhornacute: int = ...
KEY_uhornbelowdot: int = ...
KEY_uhorngrave: int = ...
KEY_uhornhook: int = ...
KEY_uhorntilde: int = ...
KEY_umacron: int = ...
KEY_underbar: int = ...
KEY_underscore: int = ...
KEY_union: int = ...
KEY_uogonek: int = ...
KEY_uparrow: int = ...
KEY_upcaret: int = ...
KEY_upleftcorner: int = ...
KEY_uprightcorner: int = ...
KEY_upshoe: int = ...
KEY_upstile: int = ...
KEY_uptack: int = ...
KEY_uring: int = ...
KEY_utilde: int = ...
KEY_v: int = ...
KEY_variation: int = ...
KEY_vertbar: int = ...
KEY_vertconnector: int = ...
KEY_voicedsound: int = ...
KEY_vt: int = ...
KEY_w: int = ...
KEY_wacute: int = ...
KEY_wcircumflex: int = ...
KEY_wdiaeresis: int = ...
KEY_wgrave: int = ...
KEY_x: int = ...
KEY_xabovedot: int = ...
KEY_y: int = ...
KEY_yacute: int = ...
KEY_ybelowdot: int = ...
KEY_ycircumflex: int = ...
KEY_ydiaeresis: int = ...
KEY_yen: int = ...
KEY_ygrave: int = ...
KEY_yhook: int = ...
KEY_ytilde: int = ...
KEY_z: int = ...
KEY_zabovedot: int = ...
KEY_zacute: int = ...
KEY_zcaron: int = ...
KEY_zerosubscript: int = ...
KEY_zerosuperior: int = ...
KEY_zstroke: int = ...
MAJOR_VERSION: int = ...
MAX_TIMECOORD_AXES: int = ...
MICRO_VERSION: int = ...
MINOR_VERSION: int = ...
PARENT_RELATIVE: int = ...
PRIORITY_REDRAW: int = ...
SELECTION_CLIPBOARD: Atom = ...
SELECTION_PRIMARY = ...
SELECTION_SECONDARY = ...
SELECTION_TYPE_ATOM = ...
SELECTION_TYPE_BITMAP = ...
SELECTION_TYPE_COLORMAP = ...
SELECTION_TYPE_DRAWABLE = ...
SELECTION_TYPE_INTEGER = ...
SELECTION_TYPE_PIXMAP = ...
SELECTION_TYPE_STRING = ...
SELECTION_TYPE_WINDOW = ...
TARGET_BITMAP = ...
TARGET_COLORMAP = ...
TARGET_DRAWABLE = ...
TARGET_PIXMAP = ...
TARGET_STRING = ...
_introspection_module = ...
_namespace: str = ...
_overrides_module = ...
_version: str = ...

def add_option_entries_libgtk_only(*args, **kwargs): ...
def atom_intern(*args, **kwargs): ...
def atom_intern_static_string(*args, **kwargs): ...
def beep(*args, **kwargs): ...
def cairo_create(*args, **kwargs): ...
def cairo_draw_from_gl(*args, **kwargs): ...
def cairo_get_clip_rectangle(*args, **kwargs): ...
def cairo_get_drawing_context(*args, **kwargs): ...
def cairo_rectangle(*args, **kwargs): ...
def cairo_region(*args, **kwargs): ...
def cairo_region_create_from_surface(*args, **kwargs): ...
def cairo_set_source_color(*args, **kwargs): ...
def cairo_set_source_pixbuf(cr: cairo.Content, pixbuf: GdkPixbuf.Pixbuf, pixbuf_x: float, pixbuf_y: float) -> None: ...
def cairo_set_source_rgba(*args, **kwargs): ...
def cairo_set_source_window(*args, **kwargs): ...
def cairo_surface_create_from_pixbuf(pixbuf: GdkPixbuf.Pixbuf, scale: int, for_window: Optional[Window] = None) -> cairo.Surface: ...
def color_parse(*args, **kwargs): ...
def disable_multidevice(*args, **kwargs): ...
def drag_abort(*args, **kwargs): ...
def drag_begin(*args, **kwargs): ...
def drag_begin_for_device(*args, **kwargs): ...
def drag_begin_from_point(*args, **kwargs): ...
def drag_drop(*args, **kwargs): ...
def drag_drop_done(*args, **kwargs): ...
def drag_drop_succeeded(*args, **kwargs): ...
def drag_find_window_for_screen(*args, **kwargs): ...
def drag_get_selection(*args, **kwargs): ...
def drag_motion(*args, **kwargs): ...
def drag_status(*args, **kwargs): ...
def drop_finish(*args, **kwargs): ...
def drop_reply(*args, **kwargs): ...
def error_trap_pop(*args, **kwargs): ...
def error_trap_pop_ignored(*args, **kwargs): ...
def error_trap_push(*args, **kwargs): ...
def event_get(*args, **kwargs): ...
def event_handler_set(*args, **kwargs): ...
def event_peek(*args, **kwargs): ...
def event_request_motions(*args, **kwargs): ...
def events_get_angle(*args, **kwargs): ...
def events_get_center(*args, **kwargs): ...
def events_get_distance(*args, **kwargs): ...
def events_pending(*args, **kwargs): ...
def flush(*args, **kwargs): ...
def get_default_root_window(*args, **kwargs): ...
def get_display(*args, **kwargs): ...
def get_display_arg_name(*args, **kwargs): ...
def get_program_class(*args, **kwargs): ...
def get_show_events(*args, **kwargs): ...
def gl_error_quark(*args, **kwargs): ...
def init(*args, **kwargs): ...
def init_check(*args, **kwargs): ...
def keyboard_grab(*args, **kwargs): ...
def keyboard_ungrab(*args, **kwargs): ...
def keyval_convert_case(*args, **kwargs): ...
def keyval_from_name(*args, **kwargs): ...
def keyval_is_lower(*args, **kwargs): ...
def keyval_is_upper(*args, **kwargs): ...
def keyval_name(*args, **kwargs): ...
def keyval_to_lower(*args, **kwargs): ...
def keyval_to_unicode(*args, **kwargs): ...
def keyval_to_upper(*args, **kwargs): ...
def list_visuals(*args, **kwargs): ...
def notify_startup_complete(*args, **kwargs): ...
def notify_startup_complete_with_id(*args, **kwargs): ...
def offscreen_window_get_embedder(*args, **kwargs): ...
def offscreen_window_get_surface(*args, **kwargs): ...
def offscreen_window_set_embedder(*args, **kwargs): ...
def pango_context_get(*args, **kwargs): ...
def pango_context_get_for_display(*args, **kwargs): ...
def pango_context_get_for_screen(*args, **kwargs): ...
def parse_args(*args, **kwargs): ...
def pixbuf_get_from_surface(surface: cairo.Surface, src_x: int, src_y: int, width: int, height: int) -> Optional[GdkPixbuf.Pixbuf]: ...
def pixbuf_get_from_window(*args, **kwargs): ...
def pointer_grab(*args, **kwargs): ...
def pointer_is_grabbed(*args, **kwargs): ...
def pointer_ungrab(*args, **kwargs): ...
def pre_parse_libgtk_only(*args, **kwargs): ...
def property_delete(*args, **kwargs): ...
def property_get(*args, **kwargs): ...
def query_depths(*args, **kwargs): ...
def query_visual_types(*args, **kwargs): ...
def rectangle_intersect(*args, **kwargs): ...
def rectangle_union(*args, **kwargs): ...
def selection_convert(*args, **kwargs): ...
def selection_owner_get(*args, **kwargs): ...
def selection_owner_get_for_display(*args, **kwargs): ...
def selection_owner_set(*args, **kwargs): ...
def selection_owner_set_for_display(*args, **kwargs): ...
def selection_send_notify(*args, **kwargs): ...
def selection_send_notify_for_display(*args, **kwargs): ...
def set_allowed_backends(*args, **kwargs): ...
def set_double_click_time(*args, **kwargs): ...
def set_program_class(*args, **kwargs): ...
def set_show_events(*args, **kwargs): ...
def setting_get(*args, **kwargs): ...
def synthesize_window_state(*args, **kwargs): ...
def test_render_sync(*args, **kwargs): ...
def test_simulate_button(*args, **kwargs): ...
def test_simulate_key(*args, **kwargs): ...
def text_property_to_utf8_list_for_display(*args, **kwargs): ...
def threads_add_idle(*args, **kwargs): ...
def threads_add_timeout(*args, **kwargs): ...
def threads_add_timeout_seconds(*args, **kwargs): ...
def threads_enter(*args, **kwargs): ...
def threads_init(*args, **kwargs): ...
def threads_leave(*args, **kwargs): ...
def unicode_to_keyval(*args, **kwargs): ...
def utf8_to_string_target(*args, **kwargs): ...


class AppLaunchContext:
    def set_desktop(*args, **kwargs): ...
    def set_display(*args, **kwargs): ...
    def set_icon(*args, **kwargs): ...
    def set_icon_name(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_timestamp(*args, **kwargs): ...
    

class Atom:
    def intern(*args, **kwargs): ...
    @classmethod
    def intern_static_string(cls, atom_name: str) -> Atom: ...
    def name(self) -> str: ...
    

class Color:
    MAX_VALUE: int = ...
    blue = ...
    blue_float = ...
    green = ...
    green_float = ...
    pixel = ...
    red = ...
    red_float = ...
    
    def equal(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def from_floats(*args, **kwargs): ...
    def hash(*args, **kwargs): ...
    def parse(*args, **kwargs): ...
    def to_floats(*args, **kwargs): ...
    def to_string(*args, **kwargs): ...
    

class Cursor:
    def get_cursor_type(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def get_image(*args, **kwargs): ...
    def get_surface(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def new_for_display(*args, **kwargs): ...
    def new_from_name(*args, **kwargs): ...
    def new_from_pixbuf(*args, **kwargs): ...
    def new_from_surface(*args, **kwargs): ...
    

class Device:
    def get_associated_device(*args, **kwargs): ...
    def get_axes(*args, **kwargs): ...
    def get_axis_use(*args, **kwargs): ...
    def get_device_type(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def get_has_cursor(*args, **kwargs): ...
    def get_key(*args, **kwargs): ...
    def get_last_event_window(*args, **kwargs): ...
    def get_mode(*args, **kwargs): ...
    def get_n_axes(*args, **kwargs): ...
    def get_n_keys(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_position(*args, **kwargs): ...
    def get_position_double(*args, **kwargs): ...
    def get_product_id(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source(*args, **kwargs): ...
    def get_vendor_id(*args, **kwargs): ...
    def get_window_at_position(*args, **kwargs): ...
    def get_window_at_position_double(*args, **kwargs): ...
    def grab(*args, **kwargs): ...
    def grab_info_libgtk_only(*args, **kwargs): ...
    def list_axes(*args, **kwargs): ...
    def list_slave_devices(*args, **kwargs): ...
    def set_axis_use(*args, **kwargs): ...
    def set_key(*args, **kwargs): ...
    def set_mode(*args, **kwargs): ...
    def ungrab(*args, **kwargs): ...
    def warp(*args, **kwargs): ...
    

class DeviceManager:
    def get_client_pointer(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def list_devices(*args, **kwargs): ...
    

class DevicePad:
    def get_feature_group(*args, **kwargs): ...
    def get_group_n_modes(*args, **kwargs): ...
    def get_n_features(*args, **kwargs): ...
    def get_n_groups(*args, **kwargs): ...
    

class DevicePadInterface: ...

class DeviceTool:
    def get_hardware_id(*args, **kwargs): ...
    def get_serial(*args, **kwargs): ...
    def get_tool_type(*args, **kwargs): ...
    

class Display:
    def beep(*args, **kwargs): ...
    def close(*args, **kwargs): ...
    def device_is_grabbed(*args, **kwargs): ...
    def flush(*args, **kwargs): ...
    def get_app_launch_context(*args, **kwargs): ...
    def get_default(*args, **kwargs): ...
    def get_default_cursor_size(*args, **kwargs): ...
    def get_default_group(*args, **kwargs): ...
    def get_default_screen(*args, **kwargs): ...
    def get_default_seat(*args, **kwargs): ...
    def get_device_manager(*args, **kwargs): ...
    def get_event(*args, **kwargs): ...
    def get_maximal_cursor_size(*args, **kwargs): ...
    def get_monitor(*args, **kwargs): ...
    def get_monitor_at_point(*args, **kwargs): ...
    def get_monitor_at_window(*args, **kwargs): ...
    def get_n_monitors(*args, **kwargs): ...
    def get_n_screens(*args, **kwargs): ...
    def get_name(*args, **kwargs): ...
    def get_pointer(*args, **kwargs): ...
    def get_primary_monitor(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_window_at_pointer(*args, **kwargs): ...
    def has_pending(*args, **kwargs): ...
    def is_closed(*args, **kwargs): ...
    def keyboard_ungrab(*args, **kwargs): ...
    def list_devices(*args, **kwargs): ...
    def list_seats(*args, **kwargs): ...
    def notify_startup_complete(*args, **kwargs): ...
    def open(*args, **kwargs): ...
    def open_default_libgtk_only(*args, **kwargs): ...
    def peek_event(*args, **kwargs): ...
    def pointer_is_grabbed(*args, **kwargs): ...
    def pointer_ungrab(*args, **kwargs): ...
    def put_event(*args, **kwargs): ...
    def request_selection_notification(*args, **kwargs): ...
    def set_double_click_distance(*args, **kwargs): ...
    def set_double_click_time(*args, **kwargs): ...
    def store_clipboard(*args, **kwargs): ...
    def supports_clipboard_persistence(*args, **kwargs): ...
    def supports_composite(*args, **kwargs): ...
    def supports_cursor_alpha(*args, **kwargs): ...
    def supports_cursor_color(*args, **kwargs): ...
    def supports_input_shapes(*args, **kwargs): ...
    def supports_selection_notification(*args, **kwargs): ...
    def supports_shapes(*args, **kwargs): ...
    def sync(*args, **kwargs): ...
    def warp_pointer(*args, **kwargs): ...
    

class DisplayManager:
    def get(*args, **kwargs): ...
    def get_default_display(*args, **kwargs): ...
    def list_displays(*args, **kwargs): ...
    def open_display(*args, **kwargs): ...
    def set_default_display(*args, **kwargs): ...
    

class DragContext:
    def finish(*args, **kwargs): ...
    def get_actions(*args, **kwargs): ...
    def get_dest_window(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_drag_window(*args, **kwargs): ...
    def get_protocol(*args, **kwargs): ...
    def get_selected_action(*args, **kwargs): ...
    def get_source_window(*args, **kwargs): ...
    def get_suggested_action(*args, **kwargs): ...
    def list_targets(*args, **kwargs): ...
    def manage_dnd(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_hotspot(*args, **kwargs): ...
    

class DrawingContext:
    def get_cairo_context(*args, **kwargs): ...
    def get_clip(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def is_valid(*args, **kwargs): ...
    

class Event:
    _UNION_MEMBERS = ...
    any: EventAny
    button: EventButton
    configure: EventConfigure
    crossing: EventCrossing
    dnd: EventDND
    expose: EventExpose
    focus_change: EventFocus
    grab_broken: EventGrabBroken
    key: EventKey
    motion: EventMotion
    owner_change: EventOwnerChange
    pad_axis: EventPadAxis
    pad_button: EventPadButton
    pad_group_mode: EventPadGroupMode
    property: EventProperty
    proximity: EventProximity
    scroll: EventScroll
    selection: EventSelection
    setting: EventSetting
    touch: EventTouch
    touchpad_pinch: EventTouchpadPinch
    touchpad_swipe: EventTouchpadSwipe
    type: EventType
    visibility: EventVisibility
    window_state: EventWindowState

    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventAny:
    send_event = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...


class EventButton:
    axes: float
    button: int
    device: Device
    send_event: int
    state: ModifierType
    time: int
    type: EventType
    window: Window
    x: float
    x_root: float
    y: float
    y_root: float
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventConfigure:
    height = ...
    send_event = ...
    type = ...
    width = ...
    window = ...
    x = ...
    y = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventCrossing:
    detail = ...
    focus = ...
    mode = ...
    send_event = ...
    state = ...
    subwindow = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventDND:
    context = ...
    send_event = ...
    time = ...
    type = ...
    window = ...
    x_root = ...
    y_root = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventExpose:
    area = ...
    count = ...
    region = ...
    send_event = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventFocus:
    in_: int
    send_event: int
    type: EventType
    window: Window
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventGrabBroken:
    grab_window = ...
    implicit = ...
    keyboard = ...
    send_event = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventKey:
    group: int
    hardware_keycode: int
    is_modifier: int
    keyval: int
    length: int
    send_event: int
    state: ModifierType
    string: str
    time: int
    type: EventType
    window: Window
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventMotion:
    axes = ...
    device = ...
    is_hint = ...
    send_event = ...
    state = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventOwnerChange:
    owner = ...
    reason = ...
    selection = ...
    selection_time = ...
    send_event = ...
    time = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventPadAxis:
    group = ...
    index = ...
    mode = ...
    send_event = ...
    time = ...
    type = ...
    value = ...
    window = ...
    

class EventPadButton:
    button = ...
    group = ...
    mode = ...
    send_event = ...
    time = ...
    type = ...
    window = ...
    

class EventPadGroupMode:
    group = ...
    mode = ...
    send_event = ...
    time = ...
    type = ...
    window = ...
    

class EventProperty:
    atom = ...
    send_event = ...
    state = ...
    time = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventProximity:
    device = ...
    send_event = ...
    time = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventScroll:
    delta_x = ...
    delta_y = ...
    device = ...
    direction = ...
    is_stop = ...
    send_event = ...
    state = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventSelection:
    property = ...
    requestor = ...
    selection = ...
    send_event = ...
    target = ...
    time = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventSequence: ...

class EventSetting:
    action = ...
    name = ...
    send_event = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventTouch:
    axes = ...
    device = ...
    emulating_pointer = ...
    send_event = ...
    sequence = ...
    state = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventTouchpadPinch:
    angle_delta = ...
    dx = ...
    dy = ...
    n_fingers = ...
    phase = ...
    scale = ...
    send_event = ...
    state = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    

class EventTouchpadSwipe:
    dx = ...
    dy = ...
    n_fingers = ...
    phase = ...
    send_event = ...
    state = ...
    time = ...
    type = ...
    window = ...
    x = ...
    x_root = ...
    y = ...
    y_root = ...
    

class EventVisibility:
    send_event = ...
    state = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class EventWindowState:
    changed_mask = ...
    new_window_state = ...
    send_event = ...
    type = ...
    window = ...
    
    def copy(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def get(*args, **kwargs): ...
    def get_axis(*args, **kwargs): ...
    def get_button(*args, **kwargs): ...
    def get_click_count(*args, **kwargs): ...
    def get_coords(*args, **kwargs): ...
    def get_device(*args, **kwargs): ...
    def get_device_tool(*args, **kwargs): ...
    def get_event_sequence(*args, **kwargs): ...
    def get_event_type(*args, **kwargs): ...
    def get_keycode(*args, **kwargs): ...
    def get_keyval(*args, **kwargs): ...
    def get_pointer_emulated(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_scancode(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_scroll_deltas(*args, **kwargs): ...
    def get_scroll_direction(*args, **kwargs): ...
    def get_seat(*args, **kwargs): ...
    def get_source_device(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_time(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def handler_set(*args, **kwargs): ...
    def is_scroll_stop_event(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek(*args, **kwargs): ...
    def put(*args, **kwargs): ...
    def request_motions(*args, **kwargs): ...
    def set_device(*args, **kwargs): ...
    def set_device_tool(*args, **kwargs): ...
    def set_screen(*args, **kwargs): ...
    def set_source_device(*args, **kwargs): ...
    def triggers_context_menu(*args, **kwargs): ...
    

class FrameClock:
    def begin_updating(*args, **kwargs): ...
    def end_updating(*args, **kwargs): ...
    def get_current_timings(*args, **kwargs): ...
    def get_frame_counter(*args, **kwargs): ...
    def get_frame_time(*args, **kwargs): ...
    def get_history_start(*args, **kwargs): ...
    def get_refresh_info(*args, **kwargs): ...
    def get_timings(*args, **kwargs): ...
    def request_phase(*args, **kwargs): ...
    

class FrameTimings:
    def get_complete(*args, **kwargs): ...
    def get_frame_counter(*args, **kwargs): ...
    def get_frame_time(*args, **kwargs): ...
    def get_predicted_presentation_time(*args, **kwargs): ...
    def get_presentation_time(*args, **kwargs): ...
    def get_refresh_interval(*args, **kwargs): ...
    def ref(*args, **kwargs): ...
    def unref(*args, **kwargs): ...
    

class GLContext:
    def clear_current(*args, **kwargs): ...
    def get_current(*args, **kwargs): ...
    def get_debug_enabled(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def get_forward_compatible(*args, **kwargs): ...
    def get_required_version(*args, **kwargs): ...
    def get_shared_context(*args, **kwargs): ...
    def get_use_es(*args, **kwargs): ...
    def get_version(*args, **kwargs): ...
    def get_window(*args, **kwargs): ...
    def is_legacy(*args, **kwargs): ...
    def make_current(*args, **kwargs): ...
    def realize(*args, **kwargs): ...
    def set_debug_enabled(*args, **kwargs): ...
    def set_forward_compatible(*args, **kwargs): ...
    def set_required_version(*args, **kwargs): ...
    def set_use_es(*args, **kwargs): ...
    

class Geometry:
    base_height: int
    base_width: int
    height_inc: int
    max_aspect: float
    max_height: int
    max_width: int
    min_aspect: float
    min_height: int
    min_width: int
    width_inc: int
    win_gravity: Gravity
    

class Keymap:
    def add_virtual_modifiers(*args, **kwargs): ...
    def get_caps_lock_state(*args, **kwargs): ...
    def get_default(*args, **kwargs): ...
    def get_direction(*args, **kwargs): ...
    def get_entries_for_keycode(*args, **kwargs): ...
    def get_entries_for_keyval(*args, **kwargs): ...
    def get_for_display(*args, **kwargs): ...
    def get_modifier_mask(*args, **kwargs): ...
    def get_modifier_state(*args, **kwargs): ...
    def get_num_lock_state(*args, **kwargs): ...
    def get_scroll_lock_state(*args, **kwargs): ...
    def have_bidi_layouts(*args, **kwargs): ...
    def lookup_key(*args, **kwargs): ...
    def map_virtual_modifiers(*args, **kwargs): ...
    def translate_keyboard_state(*args, **kwargs): ...
    

class KeymapKey:
    group = ...
    keycode = ...
    level = ...
    

class Monitor:
    def get_display(*args, **kwargs): ...
    def get_geometry(*args, **kwargs): ...
    def get_height_mm(*args, **kwargs): ...
    def get_manufacturer(*args, **kwargs): ...
    def get_model(*args, **kwargs): ...
    def get_refresh_rate(*args, **kwargs): ...
    def get_scale_factor(*args, **kwargs): ...
    def get_subpixel_layout(*args, **kwargs): ...
    def get_width_mm(*args, **kwargs): ...
    def get_workarea(*args, **kwargs): ...
    def is_primary(*args, **kwargs): ...
    

class Point:
    x = ...
    y = ...
    

class RGBA:
    alpha: float = ...
    blue: float = ...
    green: float = ...
    red: float = ...
    
    def __init__(self, blue: float = 1.0, green: float = 1.0, red: float = 1.0, alpha: float = 1.0) -> None: ...
    def equal(*args, **kwargs): ...
    def free(*args, **kwargs): ...
    def hash(*args, **kwargs): ...
    def parse(self, spec: str) -> bool: ...
    def to_color(self) -> None: ...
    def to_string(self) -> str: ...
    
    def from_color(self, *args, **kwargs): ...
    

class Rectangle:
    height = int
    width = int
    x = int
    y = int
    
    def equal(*args, **kwargs): ...
    def intersect(*args, **kwargs): ...
    def union(*args, **kwargs): ...
    

class Screen(GObject.Object):
    def get_active_window(*args, **kwargs): ...
    @classmethod
    def get_default(cls) -> Optional[Screen]: ...
    def get_display(*args, **kwargs): ...
    def get_font_options(*args, **kwargs): ...
    def get_height(*args, **kwargs): ...
    def get_height_mm(*args, **kwargs): ...
    def get_monitor_at_point(*args, **kwargs): ...
    def get_monitor_at_window(*args, **kwargs): ...
    def get_monitor_geometry(*args, **kwargs): ...
    def get_monitor_height_mm(*args, **kwargs): ...
    def get_monitor_plug_name(*args, **kwargs): ...
    def get_monitor_scale_factor(*args, **kwargs): ...
    def get_monitor_width_mm(*args, **kwargs): ...
    def get_monitor_workarea(*args, **kwargs): ...
    def get_n_monitors(*args, **kwargs): ...
    def get_number(*args, **kwargs): ...
    def get_primary_monitor(*args, **kwargs): ...
    def get_resolution(*args, **kwargs): ...
    def get_rgba_visual(*args, **kwargs): ...
    def get_root_window(*args, **kwargs): ...
    def get_setting(*args, **kwargs): ...
    def get_system_visual(*args, **kwargs): ...
    def get_toplevel_windows(*args, **kwargs): ...
    def get_width(*args, **kwargs): ...
    def get_width_mm(*args, **kwargs): ...
    def get_window_stack(*args, **kwargs): ...
    def height(*args, **kwargs): ...
    def height_mm(*args, **kwargs): ...
    def is_composited(*args, **kwargs): ...
    def list_visuals(*args, **kwargs): ...
    def make_display_name(*args, **kwargs): ...
    def set_font_options(*args, **kwargs): ...
    def set_resolution(*args, **kwargs): ...
    def width(*args, **kwargs): ...
    def width_mm(*args, **kwargs): ...
    

class Seat:
    parent_instance = ...
    
    def get_capabilities(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def get_keyboard(*args, **kwargs): ...
    def get_pointer(*args, **kwargs): ...
    def get_slaves(*args, **kwargs): ...
    def grab(*args, **kwargs): ...
    def ungrab(*args, **kwargs): ...
    

class TimeCoord:
    axes = ...
    time = ...
    

class Visual(GObject.Object):
    def get_best(*args, **kwargs): ...
    def get_best_depth(*args, **kwargs): ...
    def get_best_type(*args, **kwargs): ...
    def get_best_with_both(*args, **kwargs): ...
    def get_best_with_depth(*args, **kwargs): ...
    def get_best_with_type(*args, **kwargs): ...
    def get_bits_per_rgb(*args, **kwargs): ...
    def get_blue_pixel_details(*args, **kwargs): ...
    def get_byte_order(*args, **kwargs): ...
    def get_colormap_size(*args, **kwargs): ...
    def get_depth(*args, **kwargs): ...
    def get_green_pixel_details(*args, **kwargs): ...
    def get_red_pixel_details(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_system(*args, **kwargs): ...
    def get_visual_type(*args, **kwargs): ...
    

class Window:
    def at_pointer(*args, **kwargs): ...
    def beep(*args, **kwargs): ...
    def begin_draw_frame(*args, **kwargs): ...
    def begin_move_drag(*args, **kwargs): ...
    def begin_move_drag_for_device(*args, **kwargs): ...
    def begin_paint_rect(*args, **kwargs): ...
    def begin_paint_region(*args, **kwargs): ...
    def begin_resize_drag(*args, **kwargs): ...
    def begin_resize_drag_for_device(*args, **kwargs): ...
    def cairo_create(*args, **kwargs): ...
    def configure_finished(*args, **kwargs): ...
    def constrain_size(*args, **kwargs): ...
    def coords_from_parent(*args, **kwargs): ...
    def coords_to_parent(*args, **kwargs): ...
    def create_gl_context(*args, **kwargs): ...
    def create_similar_image_surface(*args, **kwargs): ...
    def create_similar_surface(*args, **kwargs): ...
    def deiconify(*args, **kwargs): ...
    def destroy(*args, **kwargs): ...
    def destroy_notify(*args, **kwargs): ...
    def enable_synchronized_configure(*args, **kwargs): ...
    def end_draw_frame(*args, **kwargs): ...
    def end_paint(*args, **kwargs): ...
    def ensure_native(*args, **kwargs): ...
    def flush(*args, **kwargs): ...
    def focus(*args, **kwargs): ...
    def freeze_toplevel_updates_libgtk_only(*args, **kwargs): ...
    def freeze_updates(*args, **kwargs): ...
    def fullscreen(*args, **kwargs): ...
    def fullscreen_on_monitor(*args, **kwargs): ...
    def geometry_changed(*args, **kwargs): ...
    def get_accept_focus(*args, **kwargs): ...
    def get_background_pattern(*args, **kwargs): ...
    def get_children(*args, **kwargs): ...
    def get_children_with_user_data(*args, **kwargs): ...
    def get_clip_region(*args, **kwargs): ...
    def get_composited(*args, **kwargs): ...
    def get_cursor(*args, **kwargs): ...
    def get_decorations(*args, **kwargs): ...
    def get_device_cursor(*args, **kwargs): ...
    def get_device_events(*args, **kwargs): ...
    def get_device_position(*args, **kwargs): ...
    def get_device_position_double(*args, **kwargs): ...
    def get_display(*args, **kwargs): ...
    def get_drag_protocol(*args, **kwargs): ...
    def get_effective_parent(*args, **kwargs): ...
    def get_effective_toplevel(*args, **kwargs): ...
    def get_event_compression(*args, **kwargs): ...
    def get_events(*args, **kwargs): ...
    def get_focus_on_map(*args, **kwargs): ...
    def get_frame_clock(*args, **kwargs): ...
    def get_frame_extents(*args, **kwargs): ...
    def get_fullscreen_mode(*args, **kwargs): ...
    def get_geometry(*args, **kwargs): ...
    def get_group(*args, **kwargs): ...
    def get_height(*args, **kwargs): ...
    def get_modal_hint(*args, **kwargs): ...
    def get_origin(*args, **kwargs): ...
    def get_parent(*args, **kwargs): ...
    def get_pass_through(*args, **kwargs): ...
    def get_pointer(*args, **kwargs): ...
    def get_position(*args, **kwargs): ...
    def get_root_coords(*args, **kwargs): ...
    def get_root_origin(*args, **kwargs): ...
    def get_scale_factor(*args, **kwargs): ...
    def get_screen(*args, **kwargs): ...
    def get_source_events(*args, **kwargs): ...
    def get_state(*args, **kwargs): ...
    def get_support_multidevice(*args, **kwargs): ...
    def get_toplevel(*args, **kwargs): ...
    def get_type_hint(*args, **kwargs): ...
    def get_update_area(*args, **kwargs): ...
    def get_user_data(*args, **kwargs): ...
    def get_visible_region(*args, **kwargs): ...
    def get_visual(*args, **kwargs): ...
    def get_width(*args, **kwargs): ...
    def get_window_type(*args, **kwargs): ...
    def has_native(*args, **kwargs): ...
    def hide(*args, **kwargs): ...
    def iconify(*args, **kwargs): ...
    def input_shape_combine_region(*args, **kwargs): ...
    def invalidate_maybe_recurse(*args, **kwargs): ...
    def invalidate_rect(*args, **kwargs): ...
    def invalidate_region(*args, **kwargs): ...
    def is_destroyed(*args, **kwargs): ...
    def is_input_only(*args, **kwargs): ...
    def is_shaped(*args, **kwargs): ...
    def is_viewable(*args, **kwargs): ...
    def is_visible(*args, **kwargs): ...
    def lower(*args, **kwargs): ...
    def mark_paint_from_clip(*args, **kwargs): ...
    def maximize(*args, **kwargs): ...
    def merge_child_input_shapes(*args, **kwargs): ...
    def merge_child_shapes(*args, **kwargs): ...
    def move(*args, **kwargs): ...
    def move_region(*args, **kwargs): ...
    def move_resize(*args, **kwargs): ...
    def move_to_rect(*args, **kwargs): ...
    def new(*args, **kwargs): ...
    def peek_children(*args, **kwargs): ...
    def process_all_updates(*args, **kwargs): ...
    def process_updates(*args, **kwargs): ...
    def raise_(*args, **kwargs): ...
    def register_dnd(*args, **kwargs): ...
    def reparent(*args, **kwargs): ...
    def resize(*args, **kwargs): ...
    def restack(*args, **kwargs): ...
    def scroll(*args, **kwargs): ...
    def set_accept_focus(*args, **kwargs): ...
    def set_background(*args, **kwargs): ...
    def set_background_pattern(*args, **kwargs): ...
    def set_background_rgba(*args, **kwargs): ...
    def set_child_input_shapes(*args, **kwargs): ...
    def set_child_shapes(*args, **kwargs): ...
    def set_composited(*args, **kwargs): ...
    def set_cursor(self, cursor: Optional[Cursor]) -> None: ...
    def set_debug_updates(*args, **kwargs): ...
    def set_decorations(*args, **kwargs): ...
    def set_device_cursor(*args, **kwargs): ...
    def set_device_events(*args, **kwargs): ...
    def set_event_compression(*args, **kwargs): ...
    def set_events(*args, **kwargs): ...
    def set_focus_on_map(*args, **kwargs): ...
    def set_fullscreen_mode(*args, **kwargs): ...
    def set_functions(*args, **kwargs): ...
    def set_geometry_hints(*args, **kwargs): ...
    def set_group(*args, **kwargs): ...
    def set_icon_list(*args, **kwargs): ...
    def set_icon_name(*args, **kwargs): ...
    def set_keep_above(*args, **kwargs): ...
    def set_keep_below(*args, **kwargs): ...
    def set_modal_hint(*args, **kwargs): ...
    def set_opacity(*args, **kwargs): ...
    def set_opaque_region(*args, **kwargs): ...
    def set_override_redirect(*args, **kwargs): ...
    def set_pass_through(*args, **kwargs): ...
    def set_role(*args, **kwargs): ...
    def set_shadow_width(*args, **kwargs): ...
    def set_skip_pager_hint(*args, **kwargs): ...
    def set_skip_taskbar_hint(*args, **kwargs): ...
    def set_source_events(*args, **kwargs): ...
    def set_startup_id(*args, **kwargs): ...
    def set_static_gravities(*args, **kwargs): ...
    def set_support_multidevice(*args, **kwargs): ...
    def set_title(*args, **kwargs): ...
    def set_transient_for(*args, **kwargs): ...
    def set_type_hint(*args, **kwargs): ...
    def set_urgency_hint(*args, **kwargs): ...
    def set_user_data(*args, **kwargs): ...
    def shape_combine_region(*args, **kwargs): ...
    def show(*args, **kwargs): ...
    def show_unraised(*args, **kwargs): ...
    def show_window_menu(*args, **kwargs): ...
    def stick(*args, **kwargs): ...
    def thaw_toplevel_updates_libgtk_only(*args, **kwargs): ...
    def thaw_updates(*args, **kwargs): ...
    def unfullscreen(*args, **kwargs): ...
    def unmaximize(*args, **kwargs): ...
    def unstick(*args, **kwargs): ...
    def withdraw(*args, **kwargs): ...
    
    def do_create_surface(self, *args, **kwargs): ...
    def do_from_embedder(self, *args, **kwargs): ...
    def do_to_embedder(self, *args, **kwargs): ...
    

class WindowAttr:
    cursor = ...
    event_mask = ...
    height = ...
    override_redirect = ...
    title = ...
    type_hint = ...
    visual = ...
    wclass = ...
    width = ...
    window_type = ...
    wmclass_class = ...
    wmclass_name = ...
    x = ...
    y = ...
    

class WindowRedirect: ...


class AnchorHints(GObject.GFlags):
    FLIP = ...
    FLIP_X = ...
    FLIP_Y = ...
    RESIZE = ...
    RESIZE_X = ...
    RESIZE_Y = ...
    SLIDE = ...
    SLIDE_X = ...
    SLIDE_Y = ...

class AxisFlags(GObject.GFlags):
    DISTANCE = ...
    PRESSURE = ...
    ROTATION = ...
    SLIDER = ...
    WHEEL = ...
    X = ...
    XTILT = ...
    Y = ...
    YTILT = ...

class DragAction(GObject.GFlags):
    ASK = ...
    COPY = ...
    DEFAULT = ...
    LINK = ...
    MOVE = ...
    PRIVATE = ...

class EventMask(GObject.GFlags):
    ALL_EVENTS_MASK = ...
    BUTTON1_MOTION_MASK = ...
    BUTTON2_MOTION_MASK = ...
    BUTTON3_MOTION_MASK = ...
    BUTTON_MOTION_MASK = ...
    BUTTON_PRESS_MASK = ...
    BUTTON_RELEASE_MASK = ...
    ENTER_NOTIFY_MASK = ...
    EXPOSURE_MASK = ...
    FOCUS_CHANGE_MASK = ...
    KEY_PRESS_MASK = ...
    KEY_RELEASE_MASK = ...
    LEAVE_NOTIFY_MASK = ...
    POINTER_MOTION_HINT_MASK = ...
    POINTER_MOTION_MASK = ...
    PROPERTY_CHANGE_MASK = ...
    PROXIMITY_IN_MASK = ...
    PROXIMITY_OUT_MASK = ...
    SCROLL_MASK = ...
    SMOOTH_SCROLL_MASK = ...
    STRUCTURE_MASK = ...
    SUBSTRUCTURE_MASK = ...
    TABLET_PAD_MASK = ...
    TOUCHPAD_GESTURE_MASK = ...
    TOUCH_MASK = ...
    VISIBILITY_NOTIFY_MASK = ...

class FrameClockPhase(GObject.GFlags):
    AFTER_PAINT = ...
    BEFORE_PAINT = ...
    FLUSH_EVENTS = ...
    LAYOUT = ...
    NONE = ...
    PAINT = ...
    RESUME_EVENTS = ...
    UPDATE = ...

class ModifierType(GObject.GFlags):
    BUTTON1_MASK = ...
    BUTTON2_MASK = ...
    BUTTON3_MASK = ...
    BUTTON4_MASK = ...
    BUTTON5_MASK = ...
    CONTROL_MASK = ...
    HYPER_MASK = ...
    LOCK_MASK = ...
    META_MASK = ...
    MOD1_MASK = ...
    MOD2_MASK = ...
    MOD3_MASK = ...
    MOD4_MASK = ...
    MOD5_MASK = ...
    MODIFIER_MASK = ...
    MODIFIER_RESERVED_13_MASK = ...
    MODIFIER_RESERVED_14_MASK = ...
    MODIFIER_RESERVED_15_MASK = ...
    MODIFIER_RESERVED_16_MASK = ...
    MODIFIER_RESERVED_17_MASK = ...
    MODIFIER_RESERVED_18_MASK = ...
    MODIFIER_RESERVED_19_MASK = ...
    MODIFIER_RESERVED_20_MASK = ...
    MODIFIER_RESERVED_21_MASK = ...
    MODIFIER_RESERVED_22_MASK = ...
    MODIFIER_RESERVED_23_MASK = ...
    MODIFIER_RESERVED_24_MASK = ...
    MODIFIER_RESERVED_25_MASK = ...
    MODIFIER_RESERVED_29_MASK = ...
    RELEASE_MASK = ...
    SHIFT_MASK = ...
    SUPER_MASK = ...

class SeatCapabilities(GObject.GFlags):
    ALL = ...
    ALL_POINTING = ...
    KEYBOARD = ...
    NONE = ...
    POINTER = ...
    TABLET_STYLUS = ...
    TOUCH = ...

class WMDecoration(GObject.GFlags):
    ALL = ...
    BORDER = ...
    MAXIMIZE = ...
    MENU = ...
    MINIMIZE = ...
    RESIZEH = ...
    TITLE = ...

class WMFunction(GObject.GFlags):
    ALL = ...
    CLOSE = ...
    MAXIMIZE = ...
    MINIMIZE = ...
    MOVE = ...
    RESIZE = ...

class WindowAttributesType(GObject.GFlags):
    CURSOR = ...
    NOREDIR = ...
    TITLE = ...
    TYPE_HINT = ...
    VISUAL = ...
    WMCLASS = ...
    X = ...
    Y = ...

class WindowHints(GObject.GFlags):
    ASPECT = ...
    BASE_SIZE = ...
    MAX_SIZE = ...
    MIN_SIZE = ...
    POS = ...
    RESIZE_INC = ...
    USER_POS = ...
    USER_SIZE = ...
    WIN_GRAVITY = ...

class WindowState(GObject.GFlags):
    ABOVE = ...
    BELOW = ...
    BOTTOM_RESIZABLE = ...
    BOTTOM_TILED = ...
    FOCUSED = ...
    FULLSCREEN = ...
    ICONIFIED = ...
    LEFT_RESIZABLE = ...
    LEFT_TILED = ...
    MAXIMIZED = ...
    RIGHT_RESIZABLE = ...
    RIGHT_TILED = ...
    STICKY = ...
    TILED = ...
    TOP_RESIZABLE = ...
    TOP_TILED = ...
    WITHDRAWN = ...

class AxisUse(GObject.GEnum):
    DISTANCE = ...
    IGNORE = ...
    LAST = ...
    PRESSURE = ...
    ROTATION = ...
    SLIDER = ...
    WHEEL = ...
    X = ...
    XTILT = ...
    Y = ...
    YTILT = ...

class ByteOrder(GObject.GEnum):
    LSB_FIRST = ...
    MSB_FIRST = ...

class CrossingMode(GObject.GEnum):
    DEVICE_SWITCH = ...
    GRAB = ...
    GTK_GRAB = ...
    GTK_UNGRAB = ...
    NORMAL = ...
    STATE_CHANGED = ...
    TOUCH_BEGIN = ...
    TOUCH_END = ...
    UNGRAB = ...

class CursorType(GObject.GEnum):
    ARROW = ...
    BASED_ARROW_DOWN = ...
    BASED_ARROW_UP = ...
    BLANK_CURSOR = ...
    BOAT = ...
    BOGOSITY = ...
    BOTTOM_LEFT_CORNER = ...
    BOTTOM_RIGHT_CORNER = ...
    BOTTOM_SIDE = ...
    BOTTOM_TEE = ...
    BOX_SPIRAL = ...
    CENTER_PTR = ...
    CIRCLE = ...
    CLOCK = ...
    COFFEE_MUG = ...
    CROSS = ...
    CROSSHAIR = ...
    CROSS_REVERSE = ...
    CURSOR_IS_PIXMAP = ...
    DIAMOND_CROSS = ...
    DOT = ...
    DOTBOX = ...
    DOUBLE_ARROW = ...
    DRAFT_LARGE = ...
    DRAFT_SMALL = ...
    DRAPED_BOX = ...
    EXCHANGE = ...
    FLEUR = ...
    GOBBLER = ...
    GUMBY = ...
    HAND1 = ...
    HAND2 = ...
    HEART = ...
    ICON = ...
    IRON_CROSS = ...
    LAST_CURSOR = ...
    LEFTBUTTON = ...
    LEFT_PTR = ...
    LEFT_SIDE = ...
    LEFT_TEE = ...
    LL_ANGLE = ...
    LR_ANGLE = ...
    MAN = ...
    MIDDLEBUTTON = ...
    MOUSE = ...
    PENCIL = ...
    PIRATE = ...
    PLUS = ...
    QUESTION_ARROW = ...
    RIGHTBUTTON = ...
    RIGHT_PTR = ...
    RIGHT_SIDE = ...
    RIGHT_TEE = ...
    RTL_LOGO = ...
    SAILBOAT = ...
    SB_DOWN_ARROW = ...
    SB_H_DOUBLE_ARROW = ...
    SB_LEFT_ARROW = ...
    SB_RIGHT_ARROW = ...
    SB_UP_ARROW = ...
    SB_V_DOUBLE_ARROW = ...
    SHUTTLE = ...
    SIZING = ...
    SPIDER = ...
    SPRAYCAN = ...
    STAR = ...
    TARGET = ...
    TCROSS = ...
    TOP_LEFT_ARROW = ...
    TOP_LEFT_CORNER = ...
    TOP_RIGHT_CORNER = ...
    TOP_SIDE = ...
    TOP_TEE = ...
    TREK = ...
    UL_ANGLE = ...
    UMBRELLA = ...
    UR_ANGLE = ...
    WATCH = ...
    XTERM = ...
    X_CURSOR = ...

class DevicePadFeature(GObject.GEnum):
    BUTTON = ...
    RING = ...
    STRIP = ...

class DeviceToolType(GObject.GEnum):
    AIRBRUSH = ...
    BRUSH = ...
    ERASER = ...
    LENS = ...
    MOUSE = ...
    PEN = ...
    PENCIL = ...
    UNKNOWN = ...

class DeviceType(GObject.GEnum):
    FLOATING = ...
    MASTER = ...
    SLAVE = ...

class DragCancelReason(GObject.GEnum):
    ERROR = ...
    NO_TARGET = ...
    USER_CANCELLED = ...

class DragProtocol(GObject.GEnum):
    LOCAL = ...
    MOTIF = ...
    NONE = ...
    OLE2 = ...
    ROOTWIN = ...
    WAYLAND = ...
    WIN32_DROPFILES = ...
    XDND = ...

class EventType(GObject.GEnum):
    BUTTON_PRESS = ...
    BUTTON_RELEASE = ...
    CLIENT_EVENT = ...
    CONFIGURE = ...
    DAMAGE = ...
    DELETE = ...
    DESTROY = ...
    DOUBLE_BUTTON_PRESS = ...
    DRAG_ENTER = ...
    DRAG_LEAVE = ...
    DRAG_MOTION = ...
    DRAG_STATUS = ...
    DROP_FINISHED = ...
    DROP_START = ...
    ENTER_NOTIFY = ...
    EVENT_LAST = ...
    EXPOSE = ...
    FOCUS_CHANGE = ...
    GRAB_BROKEN = ...
    KEY_PRESS = ...
    KEY_RELEASE = ...
    LEAVE_NOTIFY = ...
    MAP = ...
    MOTION_NOTIFY = ...
    NOTHING = ...
    OWNER_CHANGE = ...
    PAD_BUTTON_PRESS = ...
    PAD_BUTTON_RELEASE = ...
    PAD_GROUP_MODE = ...
    PAD_RING = ...
    PAD_STRIP = ...
    PROPERTY_NOTIFY = ...
    PROXIMITY_IN = ...
    PROXIMITY_OUT = ...
    SCROLL = ...
    SELECTION_CLEAR = ...
    SELECTION_NOTIFY = ...
    SELECTION_REQUEST = ...
    SETTING = ...
    TOUCHPAD_PINCH = ...
    TOUCHPAD_SWIPE = ...
    TOUCH_BEGIN = ...
    TOUCH_CANCEL = ...
    TOUCH_END = ...
    TOUCH_UPDATE = ...
    TRIPLE_BUTTON_PRESS = ...
    UNMAP = ...
    VISIBILITY_NOTIFY = ...
    WINDOW_STATE = ...
    _2BUTTON_PRESS = ...
    _3BUTTON_PRESS = ...

class FilterReturn(GObject.GEnum):
    CONTINUE = ...
    REMOVE = ...
    TRANSLATE = ...

class FullscreenMode(GObject.GEnum):
    ALL_MONITORS = ...
    CURRENT_MONITOR = ...

class GLError(GObject.GEnum):
    NOT_AVAILABLE = ...
    UNSUPPORTED_FORMAT = ...
    UNSUPPORTED_PROFILE = ...
    quark = ...

class GrabOwnership(GObject.GEnum):
    APPLICATION = ...
    NONE = ...
    WINDOW = ...

class GrabStatus(GObject.GEnum):
    ALREADY_GRABBED = ...
    FAILED = ...
    FROZEN = ...
    INVALID_TIME = ...
    NOT_VIEWABLE = ...
    SUCCESS = ...

class Gravity(GObject.GEnum):
    CENTER = ...
    EAST = ...
    NORTH = ...
    NORTH_EAST = ...
    NORTH_WEST = ...
    SOUTH = ...
    SOUTH_EAST = ...
    SOUTH_WEST = ...
    STATIC = ...
    WEST = ...

class InputMode(GObject.GEnum):
    DISABLED = ...
    SCREEN = ...
    WINDOW = ...

class InputSource(GObject.GEnum):
    CURSOR = ...
    ERASER = ...
    KEYBOARD = ...
    MOUSE = ...
    PEN = ...
    TABLET_PAD = ...
    TOUCHPAD = ...
    TOUCHSCREEN = ...
    TRACKPOINT = ...

class ModifierIntent(GObject.GEnum):
    CONTEXT_MENU = ...
    DEFAULT_MOD_MASK = ...
    EXTEND_SELECTION = ...
    MODIFY_SELECTION = ...
    NO_TEXT_INPUT = ...
    PRIMARY_ACCELERATOR = ...
    SHIFT_GROUP = ...

class NotifyType(GObject.GEnum):
    ANCESTOR = ...
    INFERIOR = ...
    NONLINEAR = ...
    NONLINEAR_VIRTUAL = ...
    UNKNOWN = ...
    VIRTUAL = ...

class OwnerChange(GObject.GEnum):
    CLOSE = ...
    DESTROY = ...
    NEW_OWNER = ...

class PropMode(GObject.GEnum):
    APPEND = ...
    PREPEND = ...
    REPLACE = ...

class PropertyState(GObject.GEnum):
    DELETE = ...
    NEW_VALUE = ...

class ScrollDirection(GObject.GEnum):
    DOWN = ...
    LEFT = ...
    RIGHT = ...
    SMOOTH = ...
    UP = ...

class SettingAction(GObject.GEnum):
    CHANGED = ...
    DELETED = ...
    NEW = ...

class Status(GObject.GEnum):
    ERROR = ...
    ERROR_FILE = ...
    ERROR_MEM = ...
    ERROR_PARAM = ...
    OK = ...

class SubpixelLayout(GObject.GEnum):
    HORIZONTAL_BGR = ...
    HORIZONTAL_RGB = ...
    NONE = ...
    UNKNOWN = ...
    VERTICAL_BGR = ...
    VERTICAL_RGB = ...

class TouchpadGesturePhase(GObject.GEnum):
    BEGIN = ...
    CANCEL = ...
    END = ...
    UPDATE = ...

class VisibilityState(GObject.GEnum):
    FULLY_OBSCURED = ...
    PARTIAL = ...
    UNOBSCURED = ...

class VisualType(GObject.GEnum):
    DIRECT_COLOR = ...
    GRAYSCALE = ...
    PSEUDO_COLOR = ...
    STATIC_COLOR = ...
    STATIC_GRAY = ...
    TRUE_COLOR = ...

class WindowEdge(GObject.GEnum):
    EAST = ...
    NORTH = ...
    NORTH_EAST = ...
    NORTH_WEST = ...
    SOUTH = ...
    SOUTH_EAST = ...
    SOUTH_WEST = ...
    WEST = ...

class WindowType(GObject.GEnum):
    CHILD = ...
    FOREIGN = ...
    OFFSCREEN = ...
    ROOT = ...
    SUBSURFACE = ...
    TEMP = ...
    TOPLEVEL = ...

class WindowTypeHint(GObject.GEnum):
    COMBO = ...
    DESKTOP = ...
    DIALOG = ...
    DND = ...
    DOCK = ...
    DROPDOWN_MENU = ...
    MENU = ...
    NORMAL = ...
    NOTIFICATION = ...
    POPUP_MENU = ...
    SPLASHSCREEN = ...
    TOOLBAR = ...
    TOOLTIP = ...
    UTILITY = ...
